@@ -3,8 +3,8 @@
 Base Flask application class, used by tests or to be extended
 in real applications.
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import errno
 import importlib
@@ -19,9 +19,9 @@ import jinja2
 import sqlalchemy as sa
 import yaml
 from babel.dates import LOCALTZ
-from flask import (Blueprint, Flask, _request_ctx_stack, abort,
-                   appcontext_pushed, current_app, g, render_template, request,
-                   request_started)
+from flask import Blueprint, Flask, _request_ctx_stack, abort, \
+    appcontext_pushed, current_app, g, render_template, request, \
+    request_started
 from flask.config import ConfigAttribute
 from flask.helpers import locked_cached_property
 from flask_assets import Environment as AssetsEnv
@@ -41,10 +41,10 @@ from abilian.core import extensions, redis, signals
 from abilian.core.celery import FlaskCelery
 from abilian.plugin.loader import AppLoader
 from abilian.services import converter as conversion_service
-from abilian.services import (
-    activity_service, antivirus, audit_service, auth_service, index_service,
-    preferences_service, repository_service, security_service,
-    session_repository_service, settings_service, vocabularies_service)
+from abilian.services import activity_service, antivirus, audit_service, \
+    auth_service, index_service, preferences_service, repository_service, \
+    security_service, session_repository_service, settings_service, \
+    vocabularies_service
 from abilian.services.security import Anonymous
 from abilian.web import csrf
 from abilian.web.action import Endpoint, actions
@@ -110,32 +110,29 @@ default_config.update(
     BABEL_ACCEPT_LANGUAGES=None,
     DEFAULT_COUNTRY=None,
     PLUGINS=(),
-    ADMIN_PANELS=(
-        'abilian.web.admin.panels.dashboard.DashboardPanel',
-        'abilian.web.admin.panels.audit.AuditPanel',
-        'abilian.web.admin.panels.login_sessions.LoginSessionsPanel',
-        'abilian.web.admin.panels.settings.SettingsPanel',
-        'abilian.web.admin.panels.users.UsersPanel',
-        'abilian.web.admin.panels.groups.GroupsPanel',
-        'abilian.web.admin.panels.sysinfo.SysinfoPanel',
-        'abilian.services.vocabularies.admin.VocabularyPanel',
-        'abilian.web.tags.admin.TagPanel',
-    ),
+    ADMIN_PANELS=('abilian.web.admin.panels.dashboard.DashboardPanel',
+                  'abilian.web.admin.panels.audit.AuditPanel',
+                  'abilian.web.admin.panels.login_sessions.LoginSessionsPanel',
+                  'abilian.web.admin.panels.settings.SettingsPanel',
+                  'abilian.web.admin.panels.users.UsersPanel',
+                  'abilian.web.admin.panels.groups.GroupsPanel',
+                  'abilian.web.admin.panels.sysinfo.SysinfoPanel',
+                  'abilian.services.vocabularies.admin.VocabularyPanel',
+                  'abilian.web.tags.admin.TagPanel'),
     CELERYD_MAX_TASKS_PER_CHILD=1000,
     CELERY_ACCEPT_CONTENT=['pickle', 'json', 'msgpack', 'yaml'],
     CELERY_TIMEZONE=LOCALTZ,
-    SENTRY_USER_ATTRS=('email', 'first_name', 'last_name',),
+    SENTRY_USER_ATTRS=('email', 'first_name', 'last_name'),
     SENTRY_INSTALL_CLIENT_JS=True,  # also install client JS
-    SENTRY_JS_VERSION='1.1.22',
-    SENTRY_JS_PLUGINS=('console', 'jquery', 'native', 'require',),
+    SENTRY_JS_VERSION='3.9.1',
     SESSION_COOKIE_NAME=None,
     SQLALCHEMY_POOL_RECYCLE=1800,  # 30min. default value in flask_sa is None
     SQLALCHEMY_TRACK_MODIFICATIONS=False,
-    LOGO_URL=Endpoint('abilian_static', filename='img/logo-abilian-32x32.png'),
+    LOGO_URL=Endpoint(
+        'abilian_static', filename='img/logo-abilian-32x32.png'),
     ABILIAN_UPSTREAM_INFO_ENABLED=False,  # upstream info extension
     TRACKING_CODE_SNIPPET='',  # tracking code to insert before </body>
-    MAIL_ADDRESS_TAG_CHAR=None,
-)
+    MAIL_ADDRESS_TAG_CHAR=None)
 default_config = ImmutableDict(default_config)
 
 
@@ -145,11 +142,9 @@ class Application(Flask, ServiceManager, PluginManager):
     default_config = default_config
 
     #: Custom apps may want to always load some plugins: list them here.
-    APP_PLUGINS = ('abilian.web.search',
-                   'abilian.web.tags',
-                   'abilian.web.comments',
-                   'abilian.web.uploads',
-                   'abilian.web.attachments',)
+    APP_PLUGINS = ('abilian.web.search', 'abilian.web.tags',
+                   'abilian.web.comments', 'abilian.web.uploads',
+                   'abilian.web.attachments')
 
     #: Environment variable used to locate a config file to load last (after
     #: instance config file). Use this if you want to override some settings on a
@@ -250,19 +245,26 @@ class Application(Flask, ServiceManager, PluginManager):
         self.config['BABEL_ACCEPT_LANGUAGES'] = languages
 
         self._jinja_loaders = list()
-        self.register_jinja_loaders(jinja2.PackageLoader('abilian.web',
-                                                         'templates'))
+        self.register_jinja_loaders(
+            jinja2.PackageLoader('abilian.web', 'templates'))
 
         js_filters = (('closure_js',)
                       if self.config.get('PRODUCTION', False) else None)
 
         self._assets_bundles = {
-            'css': {'options': dict(filters=('less', 'cssmin'),
-                                    output='style-%(version)s.min.css',)},
-            'js-top': {'options': dict(output='top-%(version)s.min.js',
-                                       filters=js_filters,)},
-            'js': {'options': dict(output='app-%(version)s.min.js',
-                                   filters=js_filters)},
+            'css': {
+                'options': dict(
+                    filters=('less', 'cssmin'),
+                    output='style-%(version)s.min.css')
+            },
+            'js-top': {
+                'options': dict(
+                    output='top-%(version)s.min.js', filters=js_filters)
+            },
+            'js': {
+                'options': dict(
+                    output='app-%(version)s.min.js', filters=js_filters)
+            },
         }
 
         # bundles for JS translations
@@ -270,8 +272,8 @@ class Application(Flask, ServiceManager, PluginManager):
             code = 'js-i18n-' + lang
             filename = 'lang-' + lang + '-%(version)s.min.js'
             self._assets_bundles[code] = {
-                'options': dict(output=filename,
-                                filters=js_filters),
+                'options': dict(
+                    output=filename, filters=js_filters),
             }
 
         for http_error_code in (403, 404, 500):
@@ -280,17 +282,17 @@ class Application(Flask, ServiceManager, PluginManager):
         with self.app_context():
             self.init_extensions()
             self.register_plugins()
-            self.add_access_controller('static',
-                                       allow_access_for_roles(Anonymous),
-                                       endpoint=True)
+            self.add_access_controller(
+                'static', allow_access_for_roles(Anonymous), endpoint=True)
             # debugtoolbar: this is needed to have it when not authenticated on a
             # private site. We cannot do this in init_debug_toolbar, since auth
             # service is not yet installed
             self.add_access_controller('debugtoolbar',
-                                       allow_access_for_roles(Anonymous),)
-            self.add_access_controller('_debug_toolbar.static',
-                                       allow_access_for_roles(Anonymous),
-                                       endpoint=True)
+                                       allow_access_for_roles(Anonymous))
+            self.add_access_controller(
+                '_debug_toolbar.static',
+                allow_access_for_roles(Anonymous),
+                endpoint=True)
 
         self.maybe_register_setup_wizard()
         self._finalize_assets_setup()
@@ -368,8 +370,9 @@ class Application(Flask, ServiceManager, PluginManager):
         This happens during `request_started` event, which is triggered before any
         url_value_preprocessor and `before_request` handlers.
         """
-        g.breadcrumb.append(BreadcrumbItem(icon='home',
-                                           url='/' + request.script_root))
+        g.breadcrumb.append(
+            BreadcrumbItem(
+                icon='home', url='/' + request.script_root))
 
     def check_instance_folder(self, create=False):
         """Verify instance folder exists, is a directory, and has necessary permissions.
@@ -443,15 +446,15 @@ class Application(Flask, ServiceManager, PluginManager):
 
         logging_file = self.config.get('LOGGING_CONFIG_FILE')
         if logging_file:
-            logging_file = os.path.abspath(os.path.join(self.instance_path,
-                                                        logging_file))
+            logging_file = os.path.abspath(
+                os.path.join(self.instance_path, logging_file))
         else:
             logging_file = resource_filename(__name__, 'default_logging.yml')
 
         if logging_file.endswith('.conf'):
             # old standard 'ini' file config
-            logging.config.fileConfig(logging_file,
-                                      disable_existing_loggers=False)
+            logging.config.fileConfig(
+                logging_file, disable_existing_loggers=False)
         elif logging_file.endswith('.yml'):
             # yml config file
             logging_cfg = yaml.load(open(logging_file, 'r'))
@@ -477,7 +480,8 @@ class Application(Flask, ServiceManager, PluginManager):
                     self.config['DEBUG_TB_PANELS'] = list(default_config[
                         'DEBUG_TB_PANELS'])
                     self.config['DEBUG_TB_PANELS'].append(
-                        'abilian.services.indexing.debug_toolbar.IndexedTermsDebugPanel')
+                        'abilian.services.indexing.debug_toolbar.IndexedTermsDebugPanel'
+                    )
                 init_dbt(self)
                 for view_name in self.view_functions:
                     if view_name.startswith('debugtoolbar.'):
@@ -512,9 +516,8 @@ class Application(Flask, ServiceManager, PluginManager):
         babel.timezone_selector_func = None
 
         babel.init_app(self)
-        babel.add_translations('wtforms',
-                               translations_dir='locale',
-                               domain='wtforms')
+        babel.add_translations(
+            'wtforms', translations_dir='locale', domain='wtforms')
         babel.add_translations('abilian')
         babel.localeselector(abilian.i18n.localeselector)
         babel.timezoneselector(abilian.i18n.timezoneselector)
@@ -605,9 +608,8 @@ class Application(Flask, ServiceManager, PluginManager):
                                               **options)
 
         if roles:
-            self.add_access_controller(endpoint,
-                                       allow_access_for_roles(roles),
-                                       endpoint=True)
+            self.add_access_controller(
+                endpoint, allow_access_for_roles(roles), endpoint=True)
 
     def add_access_controller(self, name, func, endpoint=False):
         """Add an access controller.
@@ -630,7 +632,7 @@ class Application(Flask, ServiceManager, PluginManager):
         """Add a new url rule for static files.
 
         :param endpoint: flask endpoint name for this url rule.
-        :param url: subpath from application static url path. No heading or trailing
+        :param url_path: subpath from application static url path. No heading or trailing
                     slash.
         :param directory: directory to serve content from.
 
@@ -644,29 +646,30 @@ class Application(Flask, ServiceManager, PluginManager):
         `/path/to/myplugin/resources` from url `http://.../static/myplugin`
         """
         url_path = self.static_url_path + '/' + url_path + '/<path:filename>'
-        self.add_url_rule(url_path,
-                          endpoint=endpoint,
-                          view_func=partial(send_file_from_directory,
-                                            directory=directory),
-                          roles=roles)
-        self.add_access_controller(endpoint,
-                                   allow_access_for_roles(Anonymous),
-                                   endpoint=True)
+        self.add_url_rule(
+            url_path,
+            endpoint=endpoint,
+            view_func=partial(
+                send_file_from_directory, directory=directory),
+            roles=roles)
+        self.add_access_controller(
+            endpoint, allow_access_for_roles(Anonymous), endpoint=True)
 
     #
     # Templating and context injection setup
     #
     def create_jinja_environment(self):
         env = Flask.create_jinja_environment(self)
-        env.globals.update(app=current_app,
-                           csrf=csrf,
-                           get_locale=babel_get_locale,
-                           local_dt=abilian.core.util.local_dt,
-                           _n=abilian.i18n._n,
-                           url_for=url_for,
-                           user_photo_url=user_photo_url,
-                           NO_VALUE=NO_VALUE,
-                           NEVER_SET=NEVER_SET,)
+        env.globals.update(
+            app=current_app,
+            csrf=csrf,
+            get_locale=babel_get_locale,
+            local_dt=abilian.core.util.local_dt,
+            _n=abilian.i18n._n,
+            url_for=url_for,
+            user_photo_url=user_photo_url,
+            NO_VALUE=NO_VALUE,
+            NEVER_SET=NEVER_SET)
         init_filters(env)
         return env
 
@@ -708,7 +711,8 @@ class Application(Flask, ServiceManager, PluginManager):
         """
         if not hasattr(self, '_jinja_loaders'):
             raise ValueError(
-                'Cannot register new jinja loaders after first template rendered')
+                'Cannot register new jinja loaders after first template rendered'
+            )
 
         self._jinja_loaders.extend(loaders)
 
@@ -815,10 +819,11 @@ class Application(Flask, ServiceManager, PluginManager):
 
         db.create_all()
         if User.query.get(0) is None:
-            root = User(id=0,
-                        last_name='SYSTEM',
-                        email='system@example.com',
-                        can_login=False)
+            root = User(
+                id=0,
+                last_name='SYSTEM',
+                email='system@example.com',
+                can_login=False)
             db.session.add(root)
             db.session.commit()
 
@@ -858,10 +863,11 @@ class Application(Flask, ServiceManager, PluginManager):
         # static minified are here
         assets.url = self.static_url_path + '/min'
         assets.append_path(str(assets_dir), assets.url)
-        self.add_static_url('min',
-                            str(assets_dir),
-                            endpoint='webassets_static',
-                            roles=Anonymous,)
+        self.add_static_url(
+            'min',
+            str(assets_dir),
+            endpoint='webassets_static',
+            roles=Anonymous)
 
     def _finalize_assets_setup(self):
         assets = self.extensions['webassets']
@@ -905,8 +911,8 @@ class Application(Flask, ServiceManager, PluginManager):
         """
         supported = self._assets_bundles.keys()
         if type_ not in supported:
-            raise KeyError("Invalid type: %s. Valid types: ", repr(type_),
-                           ', '.join(sorted(supported)))
+            raise KeyError("Invalid type: %s. Valid types: ",
+                           repr(type_), ', '.join(sorted(supported)))
 
         for asset in assets:
             if not isinstance(asset, Bundle) and callable(asset):
