@@ -1,8 +1,8 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 from multiprocessing.util import register_after_fork
 
@@ -23,11 +23,8 @@ def default_app_factory():
     return Application()
 
 
-CELERY_CONF_KEY_PREFIXES = ('CELERY_',
-                            'CELERYD_',
-                            'BROKER_',
-                            'CELERYBEAT_',
-                            'CELERYMON_',)
+CELERY_CONF_KEY_PREFIXES = ('CELERY_', 'CELERYD_', 'BROKER_', 'CELERYBEAT_',
+                            'CELERYMON_')
 
 
 def is_celery_setting(key):
