@@ -1,8 +1,8 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import logging
 import os
@@ -14,8 +14,9 @@ from jinja2 import Environment, Markup, PackageLoader
 from .base import log_config, logger
 
 #: sub-manager for config commands
-manager = Manager(description='Show config / create default config',
-                  help='Show config / create default config')
+manager = Manager(
+    description='Show config / create default config',
+    help='Show config / create default config')
 
 
 @manager.command
@@ -23,9 +24,11 @@ def show(only_path=False):
     """Show the current config.
     """
     logger.setLevel(logging.INFO)
-    infos = ['\n']
-    infos.append('Instance path: "{}"'.format(current_app.instance_path))
-    infos.append('CONFIG_ENVVAR: "{}"'.format(current_app.CONFIG_ENVVAR))
+    infos = [
+        '\n',
+        'Instance path: "{}"'.format(current_app.instance_path),
+        'CONFIG_ENVVAR: "{}"'.format(current_app.CONFIG_ENVVAR),
+    ]
 
     logger.info('\n  '.join(infos))
 
@@ -39,7 +42,7 @@ class DefaultConfig(object):
     PRODUCTION = False
     LOGGING_CONFIG_FILE = 'logging.yml'
 
-    #SQLALCHEMY_DATABASE_URI = 'sqlite:///:memory:'
+    # SQLALCHEMY_DATABASE_URI = 'sqlite:///:memory:'
     SQLALCHEMY_ECHO = False
     REDIS_URI = 'redis://localhost:6379/1'
 
