@@ -1,8 +1,8 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import time
 from collections import deque
@@ -36,19 +36,18 @@ def reindex(clear=False, progressive=False, batch_size=None):
     svc = current_app.services['indexing']
     adapted = svc.adapted
     index = svc.app_state.indexes['default']
-    session = Session(bind=current_app.db.session.get_bind(None, None),
-                      autocommit=True)
+    session = Session(
+        bind=current_app.db.session.get_bind(None, None), autocommit=True)
 
     setattr(session, '_model_changes', {})  # please flask-sqlalchemy <= 1.0
     indexed = set()
     cleared = set()
     if batch_size is not None:
         batch_size = int(batch_size)
-    strategy_kw = dict(clear=clear,
-                       progressive=progressive,
-                       batch_size=batch_size)
+
     strategy = progressive_mode if progressive else single_transaction
-    strategy = strategy(index, **strategy_kw)
+    strategy = strategy(
+        index, clear=clear, progressive=progressive, batch_size=batch_size)
     next(strategy)  # starts generator
     count_indexed = 0
 
@@ -68,15 +67,22 @@ def reindex(clear=False, progressive=False, batch_size=None):
 
         with session.begin():
             query = session.query(cls).options(sa.orm.lazyload('*'))
-            count = query.count()
+            try:
+                count = query.count()
+            except Exception as e:
+                current_app.logger.error(
+                    "Indexing error on class {}: {}".format(name, repr(e)))
+                continue
 
             if count == 0:
                 print("{}: 0".format(name))
                 continue
 
-            widgets = [name, ': ', progressbar.Counter(), '/{}'.format(count),
-                       ' ', progressbar.Timer(), ' ', progressbar.Percentage(),
-                       ' ', progressbar.Bar(), ' ', progressbar.ETA()]
+            widgets = [
+                name, ': ', progressbar.Counter(), '/{}'.format(count), ' ',
+                progressbar.Timer(), ' ', progressbar.Percentage(), ' ',
+                progressbar.Bar(), ' ', progressbar.ETA()
+            ]
             progress = progressbar.ProgressBar(widgets=widgets, maxval=count)
             progress.start()
             count_current = 0
