@@ -13,8 +13,8 @@ your entry point before anything has been imported:
  logging.getLogger('PATCH').setLevel(logging.INFO)
 
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import logging
 
@@ -52,6 +52,7 @@ class PatchLoggerAdapter(logging.LoggerAdapter):
 
         return '{}.{}'.format(location, func.__name__), kwargs
 
+
 #: logger for monkey patchs. use like this:
 #: patch_logger.info(<func>`patched_func`)
 patch_logger = PatchLoggerAdapter(_patch_logger, None)
