@@ -1,8 +1,8 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 from datetime import datetime
 
@@ -60,10 +60,10 @@ class Indexable(object):
     """
     __indexable__ = True
     __indexation_args__ = {
-        'index_to': (('object_key', (('object_key', ID(stored=True,
-                                                       unique=True)),)),
-                     ('object_type', (('object_type', ID(stored=True,
-                                                         unique=False)),)),),
+        'index_to': (
+            ('object_key', (('object_key', ID(stored=True, unique=True)),)),
+            ('object_type', (('object_type', ID(stored=True,
+                                                unique=False)),)),),
     }
 
     @classmethod
@@ -81,12 +81,12 @@ class Indexable(object):
 
 class TimestampedMixin(object):
     #: creation date
-    created_at = Column(DateTime,
-                        default=datetime.utcnow,
-                        info=SYSTEM | SEARCHABLE)
+    created_at = Column(
+        DateTime, default=datetime.utcnow, info=SYSTEM | SEARCHABLE)
     #: last modification date
-    updated_at = Column(DateTime,
-                        default=datetime.utcnow,
-                        onupdate=datetime.utcnow,
-                        info=SYSTEM | SEARCHABLE)
+    updated_at = Column(
+        DateTime,
+        default=datetime.utcnow,
+        onupdate=datetime.utcnow,
+        info=SYSTEM | SEARCHABLE)
     deleted_at = Column(DateTime, default=None, info=SYSTEM)
