@@ -1,13 +1,12 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import uuid
-from StringIO import StringIO
 
-from six import text_type
+from six import StringIO, text_type
 
 from abilian.services import repository_service as repository
 from abilian.services import session_repository_service as session_repository
