@@ -1,8 +1,8 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 from flask import current_app, request
 from flask_login import user_logged_in
@@ -21,10 +21,13 @@ class Sentry(RavenExt):
 
     @property
     def raven_js_url(self):
-        url = u'//cdn.ravenjs.com/{version}/{plugins}/raven.min.js'
+        url = '//cdn.ravenjs.com/{version}/raven.min.js'
         cfg = current_app.config
-        return url.format(version=text_type(cfg['SENTRY_JS_VERSION']),
-                          plugins=','.join(cfg['SENTRY_JS_PLUGINS']))
+        version = text_type(cfg['SENTRY_JS_VERSION'])
+        plugins = cfg.get('SENTRY_JS_PLUGINS', [])
+        if plugins:
+            version = version + '/' + ','.join(plugins)
+        return url.format(version=version)
 
 
 __all__ = ['Sentry']
