@@ -1,7 +1,7 @@
 # coding=utf-8
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 from six import text_type
 
@@ -49,32 +49,26 @@ def test_pagination_4():
 
 
 def test_slugify_basic():
-    slug = slugify(u'a b c')
-    assert slug == u'a-b-c'
+    slug = slugify('a b c')
+    assert slug == 'a-b-c'
     assert isinstance(slug, text_type)
-    assert slugify(slug) == u'a-b-c'  # idempotent
+    assert slugify(slug) == 'a-b-c'  # idempotent
 
 
 def test_slugify_separator():
-    slug = slugify(u"a-b++ c-+", u'+')
-    assert slug == u'a+b+c'
-
-
-def test_slugify_non_unicode_input():
-    slug = slugify(b"a b c")
-    assert slug == u'a-b-c'
-    assert isinstance(slug, text_type)
+    slug = slugify("a-b++ c-+", '+')
+    assert slug == 'a+b+c'
 
 
 def test_slugify_non_ascii():
-    slug = slugify(u"C'est l'été !")
-    assert slug == u'c-est-l-ete'
+    slug = slugify("C'est l'été !")
+    assert slug == 'c-est-l-ete'
 
     # with a special space character
-    slug = slugify(u"a_b\u205fc")  # U+205F: MEDIUM MATHEMATICAL SPACE
-    assert slug == u'a-b-c'
+    slug = slugify("a_b\u205fc")  # U+205F: MEDIUM MATHEMATICAL SPACE
+    assert slug == 'a-b-c'
 
     # with non-ascii translatable chars, like EN DASH U+2013 (–) and EM DASH
     # U+2014 (—).
     # this test fails if regexp subst is done after unicode normalization
-    assert slugify(u'a\u2013b\u2014c') == u'a-b-c'
+    assert slugify('a\u2013b\u2014c') == 'a-b-c'
