@@ -15,8 +15,9 @@ from .base import Service, ServiceState
 from .audit import audit_service
 from .indexing import service as index_service
 from .security import security as security_service
-from .repository import (repository as repository_service,
-                         session_repository as session_repository_service,)
+from .repository import (
+    repository as repository_service,
+    session_repository as session_repository_service,)
 from .preferences import preferences as preferences_service
 from .conversion import converter
 from .activity import ActivityService
@@ -25,11 +26,12 @@ from .settings import SettingsService
 from .vocabularies import vocabularies as vocabularies_service
 from .antivirus import service as antivirus
 
-__all__ = ['Service', 'ServiceState', 'get_service', 'audit_service',
-           'index_service', 'activity_service', 'auth_service',
-           'settings_service', 'security_service', 'preferences_service',
-           'repository_service', 'session_repository_service',
-           'vocabularies_service', 'converter', 'antivirus']
+__all__ = [
+    'Service', 'ServiceState', 'get_service', 'audit_service', 'index_service',
+    'activity_service', 'auth_service', 'settings_service', 'security_service',
+    'preferences_service', 'repository_service', 'session_repository_service',
+    'vocabularies_service', 'converter', 'antivirus'
+]
 
 auth_service = AuthService()
 activity_service = ActivityService()
