@@ -7,8 +7,8 @@ See: http://stackoverflow.com/questions/1443960/how-to-implement-the-activity-st
 
 TODO: Look wether other attributes from the spec need to be implemented.
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 from datetime import datetime
 
@@ -65,7 +65,8 @@ class ActivityEntry(db.Model):
 
     def __repr__(self):
         return ('<{}.ActivityEntry id={} actor={} verb={} object={} '
-                'target={}>'.format(
-                    self.__class__.__module__, self.id,
-                    repr(text_type(self.actor)), repr(self.verb),
-                    repr(text_type(self.object)), repr(text_type(self.target))))
+                'target={}>'.format(self.__class__.__module__, self.id,
+                                    repr(text_type(self.actor)),
+                                    repr(self.verb),
+                                    repr(text_type(self.object)),
+                                    repr(text_type(self.target))))
