@@ -8,8 +8,8 @@ TODO: In the future, we may decide to:
 - Make Models that have the __auditable__ property (set to True) auditable.
 - Make Entities that have the __auditable__ property set to False not auditable.
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import pickle
 from datetime import datetime
@@ -80,6 +80,9 @@ class Changes(object):
     def __nonzero__(self):
         return bool(self.columns) or bool(self.collections)
 
+    # Py3k compat
+    __bool__ = __nonzero__
+
 
 class AuditEntry(db.Model):
     """
@@ -106,9 +109,10 @@ class AuditEntry(db.Model):
 
     def __repr__(self):
         return '<AuditEntry id={} op={} user={} {}entity=<{} id={}>>'.format(
-            repr(self.id), {CREATION: "CREATION",
-                            DELETION: "DELETION",
-                            UPDATE: "UPDATE"}[self.op],
+            repr(self.id),
+            {CREATION: "CREATION",
+             DELETION: "DELETION",
+             UPDATE: "UPDATE"}[self.op],
             repr(text_type(self.user)), 'related '
             if self.related else '', self.entity_type, self.entity_id)
 
@@ -153,12 +157,13 @@ class AuditEntry(db.Model):
             else:
                 for val in v:
                     if isinstance(val, str):
-                        # TODO: Temp fix for errors that happen during migration
+                        # TODO: Temp fix for errors that happen during
+                        # migration
                         try:
                             val = val.decode('utf-8')
                         except:
                             current_app.logger.error(
-                                "A unicode error happened on changes %s",
+                                "A Unicode error happened on changes %s",
                                 repr(changes))
                             val = u"[[Somme error occurred. Working on it]]"
                     uv.append(val)
