@@ -1,16 +1,16 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import datetime
 from itertools import count
 
 import sqlalchemy as sa
-from six import text_type
-from sqlalchemy import (Column, Date, ForeignKey, Integer, Text, Unicode,
-                        UnicodeText)
+from six import python_2_unicode_compatible, text_type
+from sqlalchemy import Column, Date, ForeignKey, Integer, Text, Unicode, \
+    UnicodeText
 from sqlalchemy.ext.declarative import declared_attr
 from sqlalchemy.orm import backref, relationship
 from sqlalchemy.orm.attributes import NEVER_SET
@@ -23,11 +23,12 @@ from abilian.testing import BaseTestCase
 from . import CREATION, DELETION, UPDATE, AuditEntry, audit_service
 
 
+@python_2_unicode_compatible
 class IntegerCollection(db.Model):
     __tablename__ = 'integer_collection'
     id = Column(Integer, primary_key=True)
 
-    def __unicode__(self):
+    def __str__(self):
         return text_type(self.id)
 
 
@@ -56,10 +57,10 @@ class AccountRelated(db.Model):
     id = Column(Integer, primary_key=True)
 
     account_id = Column(Integer, ForeignKey(DummyAccount.id), nullable=False)
-    account = relationship(DummyAccount,
-                           backref=backref('data',
-                                           order_by='AccountRelated.id',
-                                           cascade='all, delete-orphan'))
+    account = relationship(
+        DummyAccount,
+        backref=backref(
+            'data', order_by='AccountRelated.id', cascade='all, delete-orphan'))
 
     text = Column(UnicodeText, default="")
 
@@ -71,10 +72,12 @@ class CommentRelated(db.Model):
     id = Column(Integer, primary_key=True)
 
     related_id = Column(Integer, ForeignKey(AccountRelated.id), nullable=False)
-    related = relationship(AccountRelated,
-                           backref=backref('comments',
-                                           order_by='CommentRelated.id',
-                                           cascade='all, delete-orphan'))
+    related = relationship(
+        AccountRelated,
+        backref=backref(
+            'comments',
+            order_by='CommentRelated.id',
+            cascade='all, delete-orphan'))
     text = Column(UnicodeText, default="")
 
 
@@ -114,8 +117,9 @@ class TestAudit(BaseTestCase):
         assert entry.type == UPDATE
         assert entry.entity_id == account.id
         assert entry.entity == account
-        assert entry.changes.columns == {'website':
-                                         ('', 'http://www.john.com/')}
+        assert entry.changes.columns == {
+            'website': ('', 'http://www.john.com/')
+        }
 
         account.birthday = datetime.date(2012, 12, 25)
         db.session.commit()
@@ -125,8 +129,9 @@ class TestAudit(BaseTestCase):
         assert entry.type == UPDATE
         assert entry.entity_id == account.id
         assert entry.entity == account
-        assert entry.changes.columns == {'birthday':
-                                         (None, datetime.date(2012, 12, 25))}
+        assert entry.changes.columns == {
+            'birthday': (None, datetime.date(2012, 12, 25))
+        }
 
         # content hiding
         account.password = 'new super secret password'
@@ -188,9 +193,11 @@ class TestAudit(BaseTestCase):
         assert len(changes) == 1
         assert 'data 1' in changes
         changes = changes['data 1']
-        assert changes.columns == {'text': (NEVER_SET, u'text 1'),
-                                   'account_id': (NEVER_SET, 1),
-                                   'id': (NEVER_SET, 1)}
+        assert changes.columns == {
+            'text': (NEVER_SET, u'text 1'),
+            'account_id': (NEVER_SET, 1),
+            'id': (NEVER_SET, 1)
+        }
 
         comment = CommentRelated(related=data, text='comment')
         db.session.add(comment)
@@ -205,9 +212,11 @@ class TestAudit(BaseTestCase):
         assert len(changes) == 1
         assert 'data.comments 1 1' in changes
         changes = changes['data.comments 1 1']
-        assert changes.columns == {'text': (NEVER_SET, u'comment'),
-                                   'related_id': (NEVER_SET, 1),
-                                   'id': (NEVER_SET, 1)}
+        assert changes.columns == {
+            'text': (NEVER_SET, u'comment'),
+            'related_id': (NEVER_SET, 1),
+            'id': (NEVER_SET, 1)
+        }
 
         comment = CommentRelated(related=data, text='comment 2')
         db.session.add(comment)
@@ -223,9 +232,11 @@ class TestAudit(BaseTestCase):
         assert 'data.comments 1 2' in changes
 
         changes = changes['data.comments 1 2']
-        assert changes.columns == {'text': (NEVER_SET, u'comment 2'),
-                                   'related_id': (NEVER_SET, 1),
-                                   'id': (NEVER_SET, 2)}
+        assert changes.columns == {
+            'text': (NEVER_SET, u'comment 2'),
+            'related_id': (NEVER_SET, 1),
+            'id': (NEVER_SET, 2)
+        }
 
         # deletion
         db.session.delete(comment)
