@@ -1,16 +1,16 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import logging
 from datetime import datetime, timedelta
 
 from flask import current_app, g, redirect, request, url_for
 from flask_babel import lazy_gettext as _l
-from flask_login import (current_user, login_user, user_logged_in,
-                         user_logged_out)
+from flask_login import current_user, login_user, user_logged_in, \
+    user_logged_out
 from werkzeug.exceptions import Forbidden
 
 from abilian.core.extensions import db, login_manager
@@ -46,28 +46,33 @@ def _user_photo_icon_args(icon, url_args):
     return images.user_url_args(current_user, max(icon.width, icon.height))[1]
 
 
-user_menu = NavGroup('user',
-                     'authenticated',
-                     title=lambda c: current_user.name,
-                     icon=DynamicIcon(endpoint=_user_photo_endpoint,
-                                      css='avatar',
-                                      size=20,
-                                      url_args=_user_photo_icon_args),
-                     condition=is_authenticated,
-                     items=(NavItem('user',
-                                    'logout',
-                                    title=_l(u'Logout'),
-                                    icon='log-out',
-                                    url=lambda context: url_for('login.logout'),
-                                    divider=True),))
+user_menu = NavGroup(
+    'user',
+    'authenticated',
+    title=lambda c: current_user.name,
+    icon=DynamicIcon(
+        endpoint=_user_photo_endpoint,
+        css='avatar',
+        size=20,
+        url_args=_user_photo_icon_args),
+    condition=is_authenticated,
+    items=(NavItem(
+        'user',
+        'logout',
+        title=_l(u'Logout'),
+        icon='log-out',
+        url=lambda context: url_for('login.logout'),
+        divider=True),))
 
-_ACTIONS = (NavItem('user',
-                    'login',
-                    title=_l(u'Login'),
-                    icon='log-in',
-                    url=lambda context: url_for('login.login_form'),
-                    condition=is_anonymous),
-            user_menu,)
+_ACTIONS = (
+    NavItem(
+        'user',
+        'login',
+        title=_l(u'Login'),
+        icon='log-in',
+        url=lambda context: url_for('login.login_form'),
+        condition=is_anonymous),
+    user_menu,)
 
 
 class AuthServiceState(ServiceState):
