@@ -9,8 +9,8 @@ Assumes poppler-utils and LibreOffice are installed.
 
 TODO: rename Converter into ConversionService ?
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import glob
 import hashlib
@@ -29,6 +29,7 @@ from io import BytesIO
 from pathlib import Path
 from tempfile import mkstemp
 
+import six
 from magic import Magic
 from PIL import Image
 from PIL.ExifTags import TAGS
@@ -111,8 +112,9 @@ class Converter(object):
         self.cache = Cache()
 
     def init_app(self, app):
-        self.init_work_dirs(cache_dir=Path(app.instance_path, CACHE_DIR),
-                            tmp_dir=Path(app.instance_path, TMP_DIR),)
+        self.init_work_dirs(
+            cache_dir=Path(app.instance_path, CACHE_DIR),
+            tmp_dir=Path(app.instance_path, TMP_DIR),)
 
         app.extensions['conversion'] = self
 
@@ -156,7 +158,7 @@ class Converter(object):
     def to_text(self, digest, blob, mime_type):
         """Convert a file to plain text.
 
-        Useful for full-text indexing. Returns an unicode string.
+        Useful for full-text indexing. Returns a Unicode string.
         """
         # Special case, for now (XXX).
         if mime_type.startswith("image/"):
@@ -271,8 +273,8 @@ class Converter(object):
             for line in output.split(b"\n"):
                 if b":" in line:
                     key, value = line.strip().split(b":", 1)
-                    ret["PDF:" + key] = text_type(value.strip(),
-                                                  errors="replace")
+                    ret["PDF:" + key] = text_type(
+                        value.strip(), errors="replace")
 
             return ret
 
@@ -369,9 +371,10 @@ class AbiwordTextHandler(Handler):
              make_temp_file(suffix='.txt') as out_fn:
             try:
                 os.chdir(str(tmp_dir))
-                subprocess.check_call(['abiword', '--to',
-                                       os.path.basename(out_fn),
-                                       os.path.basename(in_fn)])
+                subprocess.check_call([
+                    'abiword', '--to', os.path.basename(out_fn),
+                    os.path.basename(in_fn)
+                ])
             except Exception as e:
                 raise_from(ConversionError('abiword failed'), e)
             finally:
@@ -392,9 +395,11 @@ class AbiwordTextHandler(Handler):
 
 
 class AbiwordPDFHandler(Handler):
-    accepts_mime_types = ['application/msword',
-                          'application/vnd.oasis.opendocument.text',
-                          'text/rtf',]
+    accepts_mime_types = [
+        'application/msword',
+        'application/vnd.oasis.opendocument.text',
+        'text/rtf',
+    ]
     produces_mime_types = ['application/pdf']
 
     def convert(self, blob, **kw):
@@ -403,9 +408,10 @@ class AbiwordPDFHandler(Handler):
              make_temp_file(suffix='.pdf') as out_fn:
             try:
                 os.chdir(bytes(self.TMP_DIR))
-                subprocess.check_call(['abiword', '--to',
-                                       os.path.basename(out_fn),
-                                       os.path.basename(in_fn)])
+                subprocess.check_call([
+                    'abiword', '--to', os.path.basename(out_fn),
+                    os.path.basename(in_fn)
+                ])
             except Exception as e:
                 raise_from(ConversionError('abiword failed'), e)
             finally:
@@ -445,8 +451,7 @@ class PdfToPpmHandler(Handler):
                 converted_images = []
                 for fn in l:
                     converted = resize(
-                        open(fn, 'rb').read(),
-                        size, size, mode=FIT)
+                        open(fn, 'rb').read(), size, size, mode=FIT)
                     converted_images.append(converted)
 
                 return converted_images
@@ -505,8 +510,10 @@ class UnoconvPdfHandler(Handler):
         # Hack for my Mac, FIXME later
         if os.path.exists(
                 "/Applications/LibreOffice.app/Contents/program/python"):
-            cmd = ['/Applications/LibreOffice.app/Contents/program/python',
-                   '/usr/local/bin/unoconv', '--version']
+            cmd = [
+                '/Applications/LibreOffice.app/Contents/program/python',
+                '/usr/local/bin/unoconv', '--version'
+            ]
         else:
             cmd = [self.unoconv, '--version']
 
@@ -524,17 +531,17 @@ class UnoconvPdfHandler(Handler):
             # Hack for my Mac, FIXME later
             if os.path.exists(
                     "/Applications/LibreOffice.app/Contents/program/python"):
-                cmd = ['/Applications/LibreOffice.app/Contents/program/python',
-                       '/usr/local/bin/unoconv', '-f', 'pdf', '-o', out_fn,
-                       in_fn]
+                cmd = [
+                    '/Applications/LibreOffice.app/Contents/program/python',
+                    '/usr/local/bin/unoconv', '-f', 'pdf', '-o', out_fn, in_fn
+                ]
             else:
                 cmd = [self.unoconv, '-f', 'pdf', '-o', out_fn, in_fn]
 
             def run_uno():
                 try:
-                    self._process = subprocess.Popen(cmd,
-                                                     close_fds=True,
-                                                     cwd=bytes(self.TMP_DIR))
+                    self._process = subprocess.Popen(
+                        cmd, close_fds=True, cwd=bytes(self.TMP_DIR))
                     self._process.communicate()
                 except Exception as e:
                     logger.error('run_uno error: %s', bytes(e), exc_info=True)
@@ -630,9 +637,8 @@ class WvwareTextHandler(Handler):
             if encoding in ("binary", None):
                 encoding = "ascii"
             try:
-                converted_unicode = text_type(converted,
-                                              encoding,
-                                              errors="ignore")
+                converted_unicode = text_type(
+                    converted, encoding, errors="ignore")
             except:
                 traceback.print_exc()
                 converted_unicode = text_type(converted, errors="ignore")
@@ -660,6 +666,7 @@ def make_temp_file(blob=None, prefix='tmp', suffix="", tmp_dir=None):
     except OSError:
         pass
 
+
 # Singleton, yuck!
 converter = Converter()
 converter.register_handler(PdfToTextHandler())
