@@ -1,13 +1,13 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
-from whoosh.analysis import (CharsetFilter, LowercaseFilter, NgramFilter,
-                             PathTokenizer, RegexTokenizer)
-from whoosh.fields import (DATETIME, ID, KEYWORD, NUMERIC, TEXT, FieldType,
-                           SchemaClass)
+from whoosh.analysis import CharsetFilter, LowercaseFilter, NgramFilter, \
+    PathTokenizer, RegexTokenizer
+from whoosh.fields import DATETIME, ID, KEYWORD, NUMERIC, TEXT, FieldType, \
+    SchemaClass
 from whoosh.formats import Existence
 from whoosh.support.charset import accent_map
 
@@ -16,8 +16,9 @@ from abilian.core.util import noproxy
 from abilian.services.security.models import Anonymous, Role
 
 #: A Whoosh analyzer that splits on word boundaries and folds accents and case.
-accent_folder = (RegexTokenizer(r'\w+')  # defaults doesn't split on '.'
-                 | LowercaseFilter() | CharsetFilter(accent_map))
+accent_folder = (
+    RegexTokenizer(r'\w+')  # defaults doesn't split on '.'
+    | LowercaseFilter() | CharsetFilter(accent_map))
 
 #: Analyzer for edge-ngrams, from 2 to 6 characters long
 edge_ngram = accent_folder | NgramFilter(minsize=2, maxsize=6, at='start')
@@ -45,10 +46,8 @@ class _DefaultSearchSchema(SchemaClass):
     tag_text = TEXT(stored=False, analyzer=accent_folder)
 
     # hierarchical index of ids path ('/' is the separator)
-    parent_ids = FieldType(format=Existence(),
-                           analyzer=PathTokenizer(),
-                           stored=True,
-                           unique=False)
+    parent_ids = FieldType(
+        format=Existence(), analyzer=PathTokenizer(), stored=True, unique=False)
 
     name = TEXT(stored=True, analyzer=accent_folder)
     slug = ID(stored=True)
@@ -58,7 +57,8 @@ class _DefaultSearchSchema(SchemaClass):
 
 _default_dyn_fields = {
     '*_prefix': EdgeNgramField(),
-    '*_at': DATETIME(stored=True, sortable=True),
+    '*_at': DATETIME(
+        stored=True, sortable=True),
 }
 
 
