@@ -11,8 +11,8 @@ Based on Flask-whooshalchemy by Karl Gyllstrom.
 :copyright: (c) 2012 by Karl Gyllstrom
 :license: BSD (see LICENSE.txt)
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import logging
 import os
@@ -290,8 +290,9 @@ class WhooshIndexService(Service):
         if not fields:
             fields = self.default_search_fields
 
-        valid_fields = set(f for f in index.schema.names(check_names=fields)
-                           if prefix or not f.endswith('_prefix'))
+        valid_fields = set(
+            f for f in index.schema.names(check_names=fields)
+            if prefix or not f.endswith('_prefix'))
 
         for invalid in set(fields) - valid_fields:
             del fields[invalid]
@@ -310,11 +311,11 @@ class WhooshIndexService(Service):
             if not user.is_anonymous:
                 roles.add(indexable_role(Anonymous))
                 roles.add(indexable_role(Authenticated))
-                roles |= set(indexable_role(r)
-                             for r in security.get_roles(user))
+                roles |= set(
+                    indexable_role(r) for r in security.get_roles(user))
 
-            filter_q = wq.Or([wq.Term('allowed_roles_and_users', role)
-                              for role in roles])
+            filter_q = wq.Or(
+                [wq.Term('allowed_roles_and_users', role) for role in roles])
             filters.append(filter_q)
 
         object_types = set(object_types)
@@ -370,16 +371,15 @@ class WhooshIndexService(Service):
                 sr = results
                 results = {}
                 for typename, doc_ids in sr.groups('object_type').items():
-                    results[typename] = [sr[positions[oid]]
-                                         for oid in doc_ids[:collapse_limit]]
+                    results[typename] = [
+                        sr[positions[oid]] for oid in doc_ids[:collapse_limit]
+                    ]
 
             return results
 
     def search_for_class(self, query, cls, index='default', **search_args):
-        return self.search(query,
-                           Models=(fqcn(cls),),
-                           index=index,
-                           **search_args)
+        return self.search(
+            query, Models=(fqcn(cls),), index=index, **search_args)
 
     def register_classes(self):
         state = self.app_state
@@ -412,9 +412,10 @@ class WhooshIndexService(Service):
             return
 
         to_update = self.app_state.to_update
-        session_objs = (('new', session.new),
-                        ('deleted', session.deleted),
-                        ('changed', session.dirty),)
+        session_objs = (
+            ('new', session.new),
+            ('deleted', session.deleted),
+            ('changed', session.dirty),)
         for key, objs in session_objs:
             for obj in objs:
                 model_name = fqcn(obj.__class__)
@@ -513,9 +514,8 @@ class WhooshIndexService(Service):
                 except ValueError:
                     # logger is here to give us more infos in order to catch a weird bug
                     # that happens regularly on CI but is not reliably reproductible.
-                    logger.error('writer.add_document(%r)',
-                                 document,
-                                 exc_info=True)
+                    logger.error(
+                        'writer.add_document(%r)', document, exc_info=True)
                     raise
                 indexed.add(object_key)
 
@@ -571,9 +571,8 @@ def index_update(index, items):
                 except ValueError:
                     # logger is here to give us more infos in order to catch a weird bug
                     # that happens regularly on CI but is not reliably reproductible.
-                    logger.error('writer.add_document(%r)',
-                                 document,
-                                 exc_info=True)
+                    logger.error(
+                        'writer.add_document(%r)', document, exc_info=True)
                     raise
                 updated.add(object_key)
     except:
