@@ -1,12 +1,13 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 from datetime import datetime
 from unittest import TestCase
 
+import six
 import sqlalchemy as sa
 from whoosh.fields import NUMERIC, TEXT, Schema
 
@@ -29,12 +30,14 @@ class SANotIndexable(IdMixin, db.Model):
 
 class Indexable(IdMixin, CoreIndexable, db.Model):
     __tablename__ = 'sa_indexable'
-    __indexation_args__ = dict(index_to=(('related.name', ('name', 'text')),
-                                         ('related.description', 'text'),),)
+    __indexation_args__ = dict(
+        index_to=(
+            ('related.name', ('name', 'text')),
+            ('related.description', 'text'),),)
 
-    num = sa.Column(sa.Integer,
-                    info=SEARCHABLE | dict(index_to=(
-                        ('num', NUMERIC(numtype=int)),)),)
+    num = sa.Column(
+        sa.Integer,
+        info=SEARCHABLE | dict(index_to=(('num', NUMERIC(numtype=int)),)),)
 
 
 class SubclassEntityIndexable(Entity):
@@ -79,7 +82,7 @@ class TestSAAdapter(TestCase):
             'tag_text',
         }
         assert all(lambda f: callable(f)
-                   for f in adapter.doc_attrs.itervalues())
+                   for f in six.itervalues(adapter.doc_attrs))
 
         assert set(schema.names()) == {
             'object_key',
@@ -100,16 +103,14 @@ class TestSAAdapter(TestCase):
             'tag_text',
         }
 
-        schema = Schema(id=NUMERIC(numtype=int,
-                                   bits=64,
-                                   signed=False,
-                                   stored=True,
-                                   unique=True),)
+        schema = Schema(
+            id=NUMERIC(
+                numtype=int, bits=64, signed=False, stored=True, unique=True),)
         adapter = SAAdapter(Indexable, schema)
         assert adapter.indexable
         assert set(adapter.doc_attrs) == {'id', 'text', 'num', 'name'}
         assert all(lambda f: callable(f)
-                   for f in adapter.doc_attrs.itervalues())
+                   for f in six.itervalues(adapter.doc_attrs))
 
         assert set(schema.names()) == {'id', 'text', 'num', 'name'}
         assert isinstance(schema['text'], TEXT)
@@ -121,10 +122,11 @@ class DocumentTestCase(AppTestCase):
     def test_get_document(self):
         schema = Schema()
         adapter = SAAdapter(SubclassEntityIndexable, schema)
-        expected = dict(id=2,
-                        name='entity name',
-                        created_at=datetime(2013, 11, 28, 16, 17, 0),
-                        updated_at=datetime(2013, 11, 29, 12, 17, 58))
+        expected = dict(
+            id=2,
+            name='entity name',
+            created_at=datetime(2013, 11, 28, 16, 17, 0),
+            updated_at=datetime(2013, 11, 29, 12, 17, 58))
         obj = SubclassEntityIndexable(**expected)
         obj.slug = u'entity-name'
         expected['object_type'] = u'test_adapter.SubclassEntityIndexable'
@@ -136,15 +138,13 @@ class DocumentTestCase(AppTestCase):
         assert adapter.get_document(obj) == expected
 
         # test retrieve related attributes
-        schema = Schema(id=NUMERIC(numtype=int,
-                                   bits=64,
-                                   signed=False,
-                                   stored=True,
-                                   unique=True),)
+        schema = Schema(
+            id=NUMERIC(
+                numtype=int, bits=64, signed=False, stored=True, unique=True),)
         adapter = SAAdapter(Indexable, schema)
         expected = dict(id=1, num=42)
         obj = Indexable(**expected)
-        obj.related = type(b'Related', (object,), dict(name=None))()
+        obj.related = type(str('Related'), (object,), dict(name=None))()
         expected['name'] = obj.related.name = u'related name'
         obj.related.description = u'description text'
         expected['text'] = obj.related.name + u' ' + obj.related.description
