@@ -1,8 +1,8 @@
 """
 Models for user preferences.
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 from sqlalchemy import Column, ForeignKey, Integer, String, UniqueConstraint
 from sqlalchemy.orm import backref, relation
@@ -22,9 +22,10 @@ class UserPreference(db.Model):
     id = Column(Integer, primary_key=True, autoincrement=True)
 
     #: The user who set this preference.
-    user = relation(User,
-                    backref=backref('preferences',
-                                    cascade="all, delete, delete-orphan"))
+    user = relation(
+        User,
+        backref=backref(
+            'preferences', cascade="all, delete, delete-orphan"))
     user_id = Column(ForeignKey(User.id))
 
     #: The key
