@@ -1,14 +1,15 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import shutil
 import weakref
 from pathlib import Path
 from uuid import UUID, uuid1
 
+import six
 import sqlalchemy as sa
 from flask import _app_ctx_stack, current_app
 from flask.globals import _lookup_app_object
@@ -86,20 +87,21 @@ class RepositoryService(Service):
 
         :param:uuid: :class:`UUID` instance
         :param:content: string, bytes, or any object with a `read()` method
-        :param:encoding: encoding to use when content is unicode
+        :param:encoding: encoding to use when content is Unicode
         """
         dest = self.abs_path(uuid)
         if not dest.parent.exists():
             dest.parent.mkdir(0o775, parents=True)
 
+        if hasattr(content, 'read'):
+            content = content.read()
+
         mode = 'tw'
         if not isinstance(content, text_type):
             mode = 'bw'
             encoding = None
 
         with dest.open(mode, encoding=encoding) as f:
-            if not isinstance(content, bytes):
-                content = content.read()
             f.write(content)
 
     def delete(self, uuid):
@@ -455,15 +457,17 @@ class RepositoryTransaction(object):
         self.begin()
         self._add_to(uuid, self._set, self._deleted)
 
-        mode = 'tw'
-        if not isinstance(content, text_type):
+        if hasattr(content, 'read'):
+            content = content.read()
+
+        if isinstance(content, bytes):
             mode = 'bw'
             encoding = None
+        else:
+            mode = 'tw'
 
         dest = self.path / str(uuid)
         with dest.open(mode, encoding=encoding) as f:
-            if not isinstance(content, string_types):
-                content = content.read()
             f.write(content)
 
     def get(self, uuid):
