@@ -3,8 +3,8 @@
 May or may not be needed, since the followers / followees notions are already
 implemented in the core model.
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 
 class FollowService(object):
