@@ -2,8 +2,8 @@
 
 Every entity (and even comments) should be likeable.
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 
 class Like(object):
