@@ -72,14 +72,17 @@ class SecurityInfoDebugPanel(DebugPanel):
 
         for r in roles:
             info = roles[r]
-            info['groups'] = [u'{g} (id={g.id})'.format(g=g)
-                              for g in sorted(info['groups'],
-                                              key=lambda g: g.name)]
+            info['groups'] = [
+                u'{g} (id={g.id})'.format(g=g)
+                for g in sorted(
+                    info['groups'], key=lambda g: g.name)
+            ]
             users = sorted(
                 info['users'],
                 key=lambda u: (u.last_name.lower(), u.first_name.lower()))
-            info['users'] = [u'{u} (id={u.id}, email="{u.email}")'.format(u=u)
-                             for u in users]
+            info['users'] = [
+                u'{u} (id={u.id}, email="{u.email}")'.format(u=u) for u in users
+            ]
 
         jinja_env = current_app.jinja_env
         jinja_env.filters.update(self.jinja_env.filters)
