@@ -2,11 +2,12 @@
 """
 Security service, manages roles and permissions.
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 from functools import wraps
 from itertools import chain
+from typing import Dict, Set
 
 import sqlalchemy as sa
 from flask import current_app, g
@@ -14,7 +15,6 @@ from flask_login import current_user
 from six import string_types, text_type
 from sqlalchemy import sql
 from sqlalchemy.orm import object_session, subqueryload
-from typing import Dict, Set
 
 from abilian.core.entities import Entity
 from abilian.core.extensions import db
@@ -22,17 +22,19 @@ from abilian.core.models.subjects import Group, User
 from abilian.core.util import noproxy
 from abilian.services import Service, ServiceState
 from abilian.services.security.models import Anonymous as AnonymousRole
-from abilian.services.security.models import (
-    CREATE, DELETE, MANAGE, PERMISSIONS_ATTR, READ, WRITE, Admin, Authenticated,
-    Creator, InheritSecurity, Manager, Owner, Permission, PermissionAssignment,
-    Reader, Role, RoleAssignment, SecurityAudit, Writer)
+from abilian.services.security.models import CREATE, DELETE, MANAGE, \
+    PERMISSIONS_ATTR, READ, WRITE, Admin, Authenticated, Creator, \
+    InheritSecurity, Manager, Owner, Permission, PermissionAssignment, \
+    Reader, Role, RoleAssignment, SecurityAudit, Writer
 
 #: list of legacy supported permissions when not using :class:`Permission`
 #: instance
 PERMISSIONS = frozenset(['read', 'write', 'manage'])
 
-__all__ = ['security', 'SecurityError', 'SecurityService', 'InheritSecurity',
-           'SecurityAudit']
+__all__ = [
+    'security', 'SecurityError', 'SecurityService', 'InheritSecurity',
+    'SecurityAudit'
+]
 
 #: default security matrix
 DEFAULT_PERMISSION_ROLE = dict()
@@ -180,12 +182,13 @@ class SecurityService(Service):
         manager = self._current_user_manager(session=session)
         op = (SecurityAudit.SET_INHERIT
               if inherit_security else SecurityAudit.UNSET_INHERIT)
-        audit = SecurityAudit(manager=manager,
-                              op=op,
-                              object=obj,
-                              object_id=obj.id,
-                              object_type=obj.entity_type,
-                              object_name=obj.name)
+        audit = SecurityAudit(
+            manager=manager,
+            op=op,
+            object=obj,
+            object_id=obj.id,
+            object_type=obj.entity_type,
+            object_name=obj.name)
         session.add(audit)
         self._needs_flush()
 
@@ -349,11 +352,11 @@ class SecurityService(Service):
 
         filter_cond = []
         if users:
-            filter_cond.append(RoleAssignment.user_id.in_((u.id
-                                                           for u in users)))
+            filter_cond.append(
+                RoleAssignment.user_id.in_((u.id for u in users)))
         if groups:
-            filter_cond.append(RoleAssignment.group_id.in_((g.id
-                                                            for g in groups)))
+            filter_cond.append(
+                RoleAssignment.group_id.in_((g.id for g in groups)))
 
         query = query.filter(sql.or_(*filter_cond))
         ra_users = {}
@@ -461,11 +464,8 @@ class SecurityService(Service):
         principal = noproxy(principal)
         session = object_session(obj) if obj is not None else db.session
         manager = self._current_user_manager(session=session)
-        args = dict(role=role,
-                    object=obj,
-                    anonymous=False,
-                    user=None,
-                    group=None)
+        args = dict(
+            role=role, object=obj, anonymous=False, user=None, group=None)
 
         if (principal is AnonymousRole or
             (hasattr(principal, 'is_anonymous') and principal.is_anonymous)):
@@ -516,11 +516,8 @@ class SecurityService(Service):
         session = object_session(object) if object is not None else db.session
         manager = self._current_user_manager(session=session)
 
-        args = dict(role=role,
-                    object=object,
-                    anonymous=False,
-                    user=None,
-                    group=None)
+        args = dict(
+            role=role, object=object, anonymous=False, user=None, group=None)
         query = session.query(RoleAssignment)
         query = query.filter(RoleAssignment.role == role,
                              RoleAssignment.object == object)
@@ -770,9 +767,8 @@ class SecurityService(Service):
         pa = query_pa_no_flush(session, permission, role, obj)
 
         if not pa:
-            pa = PermissionAssignment(permission=permission,
-                                      role=role,
-                                      object=obj)
+            pa = PermissionAssignment(
+                permission=permission, role=role, object=obj)
 
         # do it in any case: it could have been found in session.deleted
         session.add(pa)
@@ -795,8 +791,11 @@ class SecurityService(Service):
 
     def filter_with_permission(self, user, permission, obj_list, inherit=False):
         user = noproxy(user)
-        return [obj for obj in obj_list
-                if self.has_permission(user, permission, obj, inherit)]
+        return [
+            obj for obj in obj_list
+            if self.has_permission(user, permission, obj, inherit)
+        ]
+
 
 # Instanciate the service
 security = SecurityService()
