@@ -1,29 +1,32 @@
 # -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import unittest
 
-from pytest import skip
+import pytest
 
 from abilian.core.entities import Entity
 from abilian.core.extensions import db
 from abilian.core.models.subjects import Group, User
 from abilian.testing import BaseTestCase
 
-from . import (READ, WRITE, Admin, Anonymous, Authenticated, Creator,
-               InheritSecurity, Owner, Permission, PermissionAssignment, Reader,
-               Role, RoleAssignment, SecurityAudit, Writer, security)
+from . import READ, WRITE, Admin, Anonymous, Authenticated, Creator, \
+    InheritSecurity, Owner, Permission, PermissionAssignment, Reader, Role, \
+    RoleAssignment, SecurityAudit, Writer, security
 
 TEST_EMAIL = u"joe@example.com"
 TEST_PASSWORD = "tototiti"
 
+skip = pytest.mark.skip
+
 
 def init_user():
-    user = User(first_name="Joe",
-                last_name="User",
-                email=TEST_EMAIL,
-                password=TEST_PASSWORD)
+    user = User(
+        first_name="Joe",
+        last_name="User",
+        email=TEST_EMAIL,
+        password=TEST_PASSWORD)
     db.session.add(user)
     db.session.flush()
 
@@ -338,9 +341,8 @@ class SecurityTestCase(IntegrationTestCase):
         assert not has_permission(user, READ, obj=obj)
         assert not has_permission(user, WRITE, obj=obj)
 
-        pa = PermissionAssignment(role=Authenticated,
-                                  permission=READ,
-                                  object=obj)
+        pa = PermissionAssignment(
+            role=Authenticated, permission=READ, object=obj)
         self.session.add(pa)
         self.session.flush()
         assert has_permission(user, READ, obj=obj)
@@ -408,13 +410,13 @@ class SecurityTestCase(IntegrationTestCase):
         obj_none = DummyModel(name='none')
         self.session.add_all([obj_reader, obj_writer, obj_none])
 
-        assigments = [PermissionAssignment(role=Reader,
-                                           permission=READ,
-                                           object=obj_reader),
-                      #
-                      PermissionAssignment(role=Writer,
-                                           permission=WRITE,
-                                           object=obj_writer)]
+        assigments = [
+            PermissionAssignment(
+                role=Reader, permission=READ, object=obj_reader),
+            #
+            PermissionAssignment(
+                role=Writer, permission=WRITE, object=obj_writer)
+        ]
         self.session.add_all(assigments)
         self.session.flush()
 
@@ -436,15 +438,14 @@ class SecurityTestCase(IntegrationTestCase):
             == [obj_writer]
 
         # Permission granted to anonymous: objects returned
-        pa = PermissionAssignment(role=Anonymous,
-                                  permission=WRITE,
-                                  object=obj_reader)
+        pa = PermissionAssignment(
+            role=Anonymous, permission=WRITE, object=obj_reader)
         self.session.add(pa)
 
         assert base_query.filter(get_filter(READ, user=user)).all() \
             == [obj_reader]
         assert set(base_query.filter(get_filter(WRITE, user=user)).all()) \
-            == set([obj_reader, obj_writer])
+            == {obj_reader, obj_writer}
         self.session.delete(pa)
         assert base_query.filter(get_filter(WRITE, user=user)).all() \
             == [obj_writer]
@@ -456,12 +457,10 @@ class SecurityTestCase(IntegrationTestCase):
         security.grant_role(user, Writer)
         self.session.flush()
 
-        assert base_query.filter(get_filter(READ, user=user)).all() == [
-            obj_reader
-        ]
-        assert base_query.filter(get_filter(WRITE, user=user)).all() == [
-            obj_writer
-        ]
+        assert base_query.filter(get_filter(
+            READ, user=user)).all() == [obj_reader]
+        assert base_query.filter(get_filter(
+            WRITE, user=user)).all() == [obj_writer]
 
         # admin role has all permissions
         # 1: local role
@@ -491,13 +490,13 @@ class SecurityTestCase(IntegrationTestCase):
 
         obj_reader.creator = user
         obj_writer.owner = user
-        assigments = [PermissionAssignment(role=Creator,
-                                           permission=READ,
-                                           object=obj_reader),
-                      #
-                      PermissionAssignment(role=Owner,
-                                           permission=WRITE,
-                                           object=obj_writer)]
+        assigments = [
+            PermissionAssignment(
+                role=Creator, permission=READ, object=obj_reader),
+            #
+            PermissionAssignment(
+                role=Owner, permission=WRITE, object=obj_writer)
+        ]
         self.session.add_all(assigments)
         self.session.flush()
 
