@@ -1,12 +1,13 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import json
 from datetime import timedelta
 
+import six
 import sqlalchemy as sa
 from six import text_type
 
@@ -48,9 +49,13 @@ class _EmptyValue(object):
     def __nonzero__(self):
         return False
 
+    # Py3k compat
+    __bool__ = __nonzero__
+
     def __repr__(self):
         return '<Empty Value>'
 
+
 #: marker for emptyness, to distinguish from None
 EmptyValue = _EmptyValue()
 
@@ -59,7 +64,7 @@ class Setting(db.Model):
     """A Setting is a very simple key/value object, key being a string
     identifier and the primary key.
 
-    value must be stored as unicode.
+    value must be stored as Unicode.
     """
     transformers = _transformers
     key = sa.Column('key', sa.String(length=1000), primary_key=True)
@@ -77,8 +82,8 @@ class Setting(db.Model):
         if not (type_ in self.transformers.encoders and
                 type_ in self.transformers.decoders):
             raise ValueError(
-                'Invalid type "{}": not encoder and/or decoder registered'.format(
-                    type_))
+                'Invalid type "{}": not encoder and/or decoder registered'.
+                format(type_))
         self._type = type_
 
     _value = sa.Column('value', sa.Text())
@@ -101,6 +106,7 @@ register = _transformers.register
 def from_int(i):
     return "{}".format(i).encode()
 
+
 register('int', from_int, int)
 
 
