@@ -4,6 +4,6 @@
 from __future__ import absolute_import, print_function, division
 
 from .models import Vocabulary  # noqa
-from .service import vocabularies, get_vocabulary  # noqa
+from .service import vocabularies, get_vocabulary
 
 __all__ = ['vocabularies']
