@@ -1,9 +1,10 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
+import six
 import sqlalchemy as sa
 from flask_sqlalchemy import BaseQuery
 from sqlalchemy import Column
@@ -52,7 +53,7 @@ class _VocabularyMeta(_BaseMeta):
         meta = d.get('Meta')
         tblprefix = 'vocabulary_'
 
-        group = slugify(meta.group or u'', u'_').encode('ascii')
+        group = slugify(meta.group or u'', u'_')
         if group:
             tblprefix += group + '_'
 
@@ -63,24 +64,27 @@ class _VocabularyMeta(_BaseMeta):
         return _BaseMeta.__new__(cls, name, bases, d)
 
 
+@six.python_2_unicode_compatible
+@six.add_metaclass(_VocabularyMeta)
 class BaseVocabulary(db.Model):
     """
     Base abstract class for vocabularies
     """
-    __metaclass__ = _VocabularyMeta
     __abstract__ = True
     query_class = VocabularyQuery
 
     id = Column(sa.Integer(), primary_key=True, autoincrement=True)
     label = Column(sa.UnicodeText(), nullable=False, unique=True)
-    active = Column(sa.Boolean(),
-                    nullable=False,
-                    server_default=sa.sql.true(),
-                    default=True)
-    default = Column(sa.Boolean(),
-                     nullable=False,
-                     server_default=sa.sql.false(),
-                     default=False)
+    active = Column(
+        sa.Boolean(),
+        nullable=False,
+        server_default=sa.sql.true(),
+        default=True)
+    default = Column(
+        sa.Boolean(),
+        nullable=False,
+        server_default=sa.sql.false(),
+        default=False)
     position = Column(sa.Integer, nullable=False, unique=True)
 
     __table_args__ = (
@@ -94,21 +98,22 @@ class BaseVocabulary(db.Model):
         label = None
         group = None
 
-    def __unicode__(self):
+    def __str__(self):
         return self.label
 
     def __repr__(self):
         fmt = ('<{module}.{cls} id={id} label={label} position={position} '
                'active={active} default={default} at 0x{addr:x}')
         cls = self.__class__
-        return fmt.format(module=cls.__module__,
-                          cls=cls.__name__,
-                          id=self.id,
-                          label=repr(self.label),
-                          position=repr(self.position),
-                          active=repr(self.active),
-                          default=repr(self.default),
-                          addr=id(self),)
+        return fmt.format(
+            module=cls.__module__,
+            cls=cls.__name__,
+            id=self.id,
+            label=repr(self.label),
+            position=repr(self.position),
+            active=repr(self.active),
+            default=repr(self.default),
+            addr=id(self),)
 
 
 @sa.event.listens_for(BaseVocabulary, "before_insert", propagate=True)
@@ -128,10 +133,11 @@ def _before_insert(mapper, connection, target):
     """
     if target.position is None:
         func = sa.sql.func
-        stmt = sa.select([func.coalesce(
-            func.max(mapper.mapped_table.c.position), -1)])
+        stmt = sa.select(
+            [func.coalesce(func.max(mapper.mapped_table.c.position), -1)])
         target.position = connection.execute(stmt).scalar() + 1
 
+
 # this is used to hold a reference to Vocabularies generated from
 # :func:`Vocabulary`. We use BaseVocabulary._decl_class_registry to find
 # existing vocabulary, but it's a WeakValueDictionary. When using model
@@ -144,10 +150,17 @@ _generated_vocabularies = []
 
 
 def Vocabulary(name, label=None, group=None):
-    cls_name = b'Vocabulary' + name.capitalize()
-    Meta = type(b'Meta', (object,),
-                dict(name=name.lower(),
-                     label=label, group=group))
+    cls_name = 'Vocabulary' + name.capitalize()
+    if six.PY2:
+        cls_name = bytes(cls_name)
+
+    _name, _label, _group = name.lower(), label, group
+
+    class Meta(object):
+        name = _name
+        label = _label
+        group = _group
+
     cls = type(cls_name, (BaseVocabulary,), dict(Meta=Meta))
     _generated_vocabularies.append(cls)
     return cls
