@@ -2,8 +2,8 @@
 """
 Vocabularies service.
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 from inspect import isclass
 
@@ -15,9 +15,11 @@ from .models import BaseVocabulary
 
 
 def _vocabularies():
-    return {cls
-            for cls in BaseVocabulary._decl_class_registry.values()
-            if isclass(cls) and issubclass(cls, BaseVocabulary)}
+    return {
+        cls
+        for cls in BaseVocabulary._decl_class_registry.values()
+        if isclass(cls) and issubclass(cls, BaseVocabulary)
+    }
 
 
 def _grouped_vocabularies():
