@@ -1,8 +1,8 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import logging
 import re
@@ -10,7 +10,7 @@ import re
 from flask import current_app, g
 from flask.signals import appcontext_pushed
 from jinja2 import Markup, Template
-from six import string_types, text_type
+from six import python_2_unicode_compatible, string_types, text_type
 
 from abilian.core.singleton import UniqueName
 from abilian.web import csrf
@@ -26,6 +26,7 @@ class Status(UniqueName):
     Action UI status names
     """
 
+
 #: default action status: show in UID, usable, not marked "current"
 ENABLED = Status(u'enabled')
 #: action is "active" or "current". For example the current navigation item.
@@ -58,6 +59,7 @@ def getset(f):
     return property(f, f)
 
 
+@python_2_unicode_compatible
 class Icon(object):
     """Base abstract class for icons.
     """
@@ -65,7 +67,7 @@ class Icon(object):
     def __html__(self):
         raise NotImplementedError
 
-    def __unicode__(self):
+    def __str__(self):
         return self.__html__()
 
 
@@ -122,9 +124,8 @@ class FAIconStacked(NamedIconBase):
         self.stack = stack
 
     def __html__(self):
-        return self.template.render(name=self.name,
-                                    second=self.second,
-                                    stack_class=self.stack)
+        return self.template.render(
+            name=self.name, second=self.second, stack_class=self.stack)
 
 
 class DynamicIcon(Icon):
@@ -166,10 +167,11 @@ class DynamicIcon(Icon):
         if self.url_args_callback is not None:
             url_args = self.url_args_callback(self, url_args)
 
-        return self.template.render(url=url_for(endpoint, **url_args),
-                                    width=self.width,
-                                    height=self.height,
-                                    css=self.css)
+        return self.template.render(
+            url=url_for(endpoint, **url_args),
+            width=self.width,
+            height=self.height,
+            css=self.css)
 
 
 class StaticIcon(DynamicIcon):
@@ -186,15 +188,11 @@ class StaticIcon(DynamicIcon):
                  height=12,
                  css='',
                  size=None):
-        DynamicIcon.__init__(self,
-                             endpoint,
-                             width,
-                             height,
-                             css,
-                             size,
-                             filename=filename)
+        DynamicIcon.__init__(
+            self, endpoint, width, height, css, size, filename=filename)
 
 
+@python_2_unicode_compatible
 class Endpoint(object):
 
     # FIXME: *args doesn't seem to be relevant.
@@ -212,8 +210,8 @@ class Endpoint(object):
         """
         return self.kwargs.copy()
 
-    def __unicode__(self):
-        return text_type(url_for(self.name, *self.args, **self.get_kwargs()))
+    def __str__(self):
+        return text_type(url_for(self.name, **self.get_kwargs()))
 
     def __repr__(self):
         return '{cls}({name!r}, *{args!r}, **{kwargs!r})'.format(
@@ -278,7 +276,7 @@ class Action(object):
         self.name = name
 
         if button is not None:
-            self.CSS_CLASS = self.CSS_CLASS + u' btn btn-{}'.format(button)
+            self.CSS_CLASS += u' btn btn-{}'.format(button)
         if css is not None:
             self.CSS_CLASS = self.CSS_CLASS + u' ' + css
         self._build_css_class()
@@ -334,9 +332,8 @@ class Action(object):
         self._title = title
 
     def _build_css_class(self):
-        css_cat = self.CSS_CLASS.format(action=self,
-                                        category=self.category,
-                                        name=self.name)
+        css_cat = self.CSS_CLASS.format(
+            action=self, category=self.category, name=self.name)
         css_cat = re.sub(r'[^ _a-zA-Z0-9-]', '-', css_cat)
         self.css_class = css_cat
 
@@ -542,7 +539,8 @@ class ActionRegistry(object):
     def init_app(self, app):
         if self.__EXTENSION_NAME in app.extensions:
             log.warning(
-                'ActionRegistry.init_app: actions already enabled on this application')
+                'ActionRegistry.init_app: actions already enabled on this application'
+            )
             return
 
         app.extensions[self.__EXTENSION_NAME] = dict(categories=dict())
