@@ -1,12 +1,13 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 from datetime import datetime, timedelta
 
 import pandas as pd
+import six
 import sqlalchemy as sa
 from flask import current_app, render_template
 from numpy import sum as numpysum
@@ -50,10 +51,11 @@ class DashboardPanel(AdminPanel):
             {'key': _('Total'), 'color': '#2ca02c', 'values': total_users}
         ]
 
-        return render_template("admin/dashboard.html",
-                               stats=stats,
-                               connections=connections,
-                               new_logins=new_logins)
+        return render_template(
+            "admin/dashboard.html",
+            stats=stats,
+            connections=connections,
+            new_logins=new_logins)
 
 
 def stats_since(dt):
@@ -161,7 +163,7 @@ def uniquelogins(sessions):
     for date in sorted(dates.keys()):
         # print u"{} : {}".format(date, len(dates[date]))
         date_epoch = unix_time_millis(datetime.strptime(date, "%Y/%m/%d"))
-        daily.append({u'x': date_epoch, u'y': len(dates[date])})
+        daily.append({'x': date_epoch, 'y': len(dates[date])})
 
     # first_day = data[0]['x']
     # last_day = data[-1]['x']
@@ -180,12 +182,20 @@ def uniquelogins(sessions):
         .groupby(pd.TimeGrouper(freq='M')) \
         .aggregate(numpysum)
 
-    for date, value in weekly_serie.iteritems():
+    for date, value in six.iteritems(weekly_serie):
+        try:
+            value = int(value)
+        except ValueError:
+            continue
         date_epoch = unix_time_millis(date)
-        weekly.append({u'x': date_epoch, u'y': value})
+        weekly.append({'x': date_epoch, 'y': value})
 
-    for date, value in monthly_serie.iteritems():
+    for date, value in six.iteritems(monthly_serie):
+        try:
+            value = int(value)
+        except ValueError:
+            continue
         date_epoch = unix_time_millis(date)
-        monthly.append({u'x': date_epoch, u'y': value})
+        monthly.append({'x': date_epoch, 'y': value})
 
     return daily, weekly, monthly
