@@ -1,8 +1,8 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 from wtforms.fields import BooleanField, StringField
 
@@ -18,8 +18,7 @@ class GroupAdminForm(Form):
     description = StringField(_l(u'Description'), filters=(strip,))
 
     public = BooleanField(
-        _l(u'Public'),
-        widget=widgets.BooleanWidget(on_off_mode=True))
+        _l(u'Public'), widget=widgets.BooleanWidget(on_off_mode=True))
 
     roles = fields.Select2MultipleField(
         _l(u'Roles'),
