@@ -1,8 +1,8 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import pygeoip
 from flask import render_template
@@ -12,8 +12,9 @@ from abilian.services.auth.models import LoginSession
 
 from ..panel import AdminPanel
 
-DATA_FILES = ('/usr/share/GeoIP/GeoIP.dat',
-              '/usr/share/GeoIP/GeoIPv6.dat',)
+DATA_FILES = (
+    '/usr/share/GeoIP/GeoIP.dat',
+    '/usr/share/GeoIP/GeoIPv6.dat',)
 
 
 class LoginSessionsPanel(AdminPanel):
