@@ -1,8 +1,8 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 from cgi import escape
 
@@ -60,8 +60,8 @@ class JsonUsersList(base.JSONView):
             5: [User.last_active],
         }
         columns = list(SORT_COLS.get(sort_col, []))
-        columns.extend([func.lower(User.last_name),
-                        func.lower(User.first_name)])
+        columns.extend(
+            [func.lower(User.last_name), func.lower(User.first_name)])
 
         direction = asc if sort_dir == 'asc' else desc
         order_by = map(direction, columns)
@@ -83,28 +83,27 @@ class JsonUsersList(base.JSONView):
             mugshot = user_photo_url(user, size=MUGSHOT_SIZE)
             name = escape(getattr(user, "name") or "")
             email = escape(getattr(user, "email") or "")
-            roles = [r
-                     for r in security.get_roles(user, no_group_roles=True)
-                     if r.assignable]
-            columns = []
-            columns.append(
-                u'<a href="{url}"><img src="{src}" width="{size}" height="{size}">'
-                u'</a>'.format(url=user_url,
-                               src=mugshot,
-                               size=MUGSHOT_SIZE))
-            columns.append(u'<a href="{url}">{name}</a>'.format(url=user_url,
-                                                                name=name))
-            columns.append(u'<a href="{url}"><em>{email}</em></a>'.format(
-                url=user_url, email=email))
-            columns.append(u'\u2713' if user.can_login else u'')
-            columns.append(render_template_string(u'''{%- for g in groups %}
-            <span class="badge badge-default">{{ g.name }}</span>
-            {%- endfor %}''',
-                                                  groups=sorted(user.groups)))
-            columns.append(render_template_string(u'''{%- for role in roles %}
-            <span class="badge badge-default">{{ role }}</span>
-            {%- endfor %}''',
-                                                  roles=roles))
+            roles = [
+                r for r in security.get_roles(
+                    user, no_group_roles=True) if r.assignable
+            ]
+            columns = [
+                '<a href="{url}"><img src="{src}" width="{size}" height="{size}">'
+                '</a>'.format(url=user_url, src=mugshot, size=MUGSHOT_SIZE),
+                '<a href="{url}">{name}</a>'.format(url=user_url, name=name),
+                '<a href="{url}"><em>{email}</em></a>'.format(url=user_url, email=email),
+                '\u2713' if user.can_login else u'',
+                render_template_string(
+                    u'''{%- for g in groups %}
+                        <span class="badge badge-default">{{ g.name }}</span>
+                    {%- endfor %}''',
+                    groups=sorted(user.groups)),
+                render_template_string(
+                    u'''{%- for role in roles %}
+                       <span class="badge badge-default">{{ role }}</span>
+                    {%- endfor %}''',
+                    roles=roles),
+            ]
 
             if user.last_active:
                 last_active = format_datetime(user.last_active)
