@@ -1,8 +1,8 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 from wtforms.fields import StringField
 
@@ -17,10 +17,7 @@ from abilian.web.forms.validators import required
 class AttachmentForm(Form):
 
     blob = FileField(
-        _l(u'file'),
-        validators=[required()],
-        filters=[strip],
-        multiple=False)
+        _l(u'file'), validators=[required()], filters=[strip], multiple=False)
 
     description = StringField(_l(u'description (optional)'), filters=[strip])
 
