@@ -1,8 +1,8 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import sqlalchemy as sa
 from flask import current_app, send_file
@@ -15,8 +15,8 @@ from abilian.i18n import _, _l
 from abilian.web import nav, url_for
 from abilian.web.action import ButtonAction, actions
 from abilian.web.blueprints import Blueprint
-from abilian.web.views import (BaseObjectView, ObjectCreate, ObjectDelete,
-                               ObjectEdit)
+from abilian.web.views import BaseObjectView, ObjectCreate, ObjectDelete, \
+    ObjectEdit
 
 from .forms import AttachmentForm
 
@@ -35,10 +35,8 @@ def register_default_view(state):
     state.app.default_view.register(Attachment, _default_attachment_view)
 
 
-UPLOAD_BUTTON = ButtonAction('form',
-                             'edit',
-                             btn_class='primary',
-                             title=_l(u'Send'))
+UPLOAD_BUTTON = ButtonAction(
+    'form', 'edit', btn_class='primary', title=_l(u'Send'))
 
 
 class BaseAttachmentView(object):
@@ -92,16 +90,17 @@ class AttachmentDownload(BaseAttachmentView, BaseObjectView):
         content_type = metadata.get('mimetype')
         stream = blob.file.open('rb')
 
-        return send_file(stream,
-                         as_attachment=True,
-                         attachment_filename=filename,
-                         mimetype=content_type,
-                         cache_timeout=0,
-                         add_etags=False,
-                         conditional=False)
+        return send_file(
+            stream,
+            as_attachment=True,
+            attachment_filename=filename,
+            mimetype=content_type,
+            cache_timeout=0,
+            add_etags=False,
+            conditional=False)
 
 
-download_view = AttachmentDownload.as_view(b'download')
+download_view = AttachmentDownload.as_view('download')
 bp.route('/<int:entity_id>/<int:object_id>/download')(download_view)
 
 
@@ -109,7 +108,7 @@ class AttachmentEdit(BaseAttachmentView, ObjectEdit):
     _message_success = _l(u'Attachment edited')
 
 
-edit_view = AttachmentEdit.as_view(b'edit')
+edit_view = AttachmentEdit.as_view('edit')
 bp.route('/<int:entity_id>/<int:object_id>/edit')(edit_view)
 
 
@@ -137,7 +136,7 @@ class AttachmentCreateView(BaseAttachmentView, ObjectCreate):
         return [UPLOAD_BUTTON]
 
 
-create_view = AttachmentCreateView.as_view(b'create')
+create_view = AttachmentCreateView.as_view('create')
 bp.route('/<int:entity_id>/create')(create_view)
 
 
@@ -145,7 +144,7 @@ class AttachmentDelete(BaseAttachmentView, ObjectDelete):
     pass
 
 
-delete_view = AttachmentDelete.as_view(b'delete')
+delete_view = AttachmentDelete.as_view('delete')
 bp.route('/<int:entity_id>/<int:object_id>/delete')(delete_view)
 
 
@@ -158,5 +157,5 @@ class AttachmentEntity(BaseObjectView):
         return redirect(url_for(self.obj))
 
 
-entity_view = AttachmentEntity.as_view(b'entity')
+entity_view = AttachmentEntity.as_view('entity')
 bp.route('/<int:object_id>/entity')(entity_view)
