@@ -1,8 +1,8 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 from wtforms.fields import TextAreaField
 
@@ -16,10 +16,12 @@ from abilian.web.forms.widgets import TextArea
 
 class CommentForm(Form):
 
-    body = TextAreaField(label=_l(u'Comment'),
-                         validators=[required()],
-                         filters=(strip,),
-                         widget=TextArea(rows=5, resizeable='vertical'),)
+    body = TextAreaField(
+        label=_l(u'Comment'),
+        validators=[required()],
+        filters=(strip,),
+        widget=TextArea(
+            rows=5, resizeable='vertical'),)
 
     class Meta:
         model = Comment
