@@ -1,8 +1,8 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 from datetime import datetime
 
@@ -18,8 +18,8 @@ from abilian.i18n import _, _l
 from abilian.web import nav, url_for
 from abilian.web.action import ButtonAction, actions
 from abilian.web.blueprints import Blueprint
-from abilian.web.views.object import (CANCEL_BUTTON, ObjectCreate, ObjectDelete,
-                                      ObjectEdit)
+from abilian.web.views.object import CANCEL_BUTTON, ObjectCreate, \
+    ObjectDelete, ObjectEdit
 
 from .forms import CommentForm
 
@@ -36,10 +36,8 @@ def register_default_view(state):
     state.app.default_view.register(Comment, _default_comment_view)
 
 
-COMMENT_BUTTON = ButtonAction('form',
-                              'edit',
-                              btn_class='primary',
-                              title=_l(u'Post'))
+COMMENT_BUTTON = ButtonAction(
+    'form', 'edit', btn_class='primary', title=_l(u'Post'))
 
 
 class BaseCommentView(object):
@@ -92,13 +90,15 @@ class CommentEditView(BaseCommentView, ObjectEdit):
     def after_populate_obj(self):
         obj_meta = self.obj.meta.setdefault('abilian.core.models.comment', {})
         history = obj_meta.setdefault('history', [])
-        history.append(dict(user_id=current_user.id,
-                            user=text_type(current_user),
-                            date=utc_dt(datetime.utcnow()).isoformat(),))
+        history.append(
+            dict(
+                user_id=current_user.id,
+                user=text_type(current_user),
+                date=utc_dt(datetime.utcnow()).isoformat(),))
         self.obj.meta.changed()
 
 
-edit_view = CommentEditView.as_view(b'edit')
+edit_view = CommentEditView.as_view('edit')
 bp.route('/<int:entity_id>/<int:object_id>/edit')(edit_view)
 
 
@@ -128,7 +128,7 @@ class CommentCreateView(BaseCommentView, ObjectCreate):
         return [COMMENT_BUTTON, CANCEL_BUTTON]
 
 
-create_view = CommentCreateView.as_view(b'create')
+create_view = CommentCreateView.as_view('create')
 bp.route('/<int:entity_id>/create')(create_view)
 
 
@@ -137,5 +137,5 @@ class CommentDeleteView(BaseCommentView, ObjectDelete):
     _message_success = _l(u"Comment deleted")
 
 
-delete_view = CommentDeleteView.as_view(b'delete')
+delete_view = CommentDeleteView.as_view('delete')
 bp.route('/<int:entity_id>/<int:object_id>/delete')(delete_view)
