@@ -1,8 +1,8 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import hashlib
 
@@ -72,9 +72,10 @@ class UserJsonListing(JSONModelSearch):
 
     def filter(self, query, q, **kwargs):
         if q:
-            query = query.filter(or_(
-                func.lower(User.first_name).like(q + "%"), func.lower(
-                    User.last_name).like(q + "%")))
+            query = query.filter(
+                or_(
+                    func.lower(User.first_name).like(q + "%"),
+                    func.lower(User.last_name).like(q + "%")))
         return query
 
     def order_by(self, query):
@@ -89,4 +90,4 @@ class UserJsonListing(JSONModelSearch):
         return d
 
 
-bp.route('/json/')(UserJsonListing.as_view(b'json_list'))
+bp.route('/json/')(UserJsonListing.as_view('json_list'))
