@@ -1,8 +1,8 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import datetime
 import logging
@@ -19,12 +19,12 @@ from flask_wtf.file import FileField as BaseFileField
 from six import string_types
 from wtforms import FieldList as BaseFieldList
 from wtforms import FormField as BaseFormField
-from wtforms import (Field, SelectField, SelectFieldBase, SelectMultipleField,
-                     ValidationError)
+from wtforms import Field, SelectField, SelectFieldBase, SelectMultipleField, \
+    ValidationError
 from wtforms.compat import text_type
 from wtforms.ext.csrf import SecureForm
-from wtforms.ext.sqlalchemy.fields import (get_pk_from_identity,
-                                           has_identity_key)
+from wtforms.ext.sqlalchemy.fields import get_pk_from_identity, \
+    has_identity_key
 from wtforms.validators import DataRequired, Optional
 from wtforms_alchemy import ModelFieldList as BaseModelFieldList
 from wtforms_alchemy import ModelFormField as BaseModelFormField
@@ -36,9 +36,11 @@ from abilian.core.util import utc_dt
 from .util import babel2datetime
 from .widgets import DateInput, DateTimeInput, FileInput, Select2, Select2Ajax
 
-__all__ = ['ModelFieldList', 'FileField', 'DateField', 'Select2Field',
-           'Select2MultipleField', 'QuerySelect2Field', 'JsonSelect2Field',
-           'JsonSelect2MultipleField', 'FormField']
+__all__ = [
+    'ModelFieldList', 'FileField', 'DateField', 'Select2Field',
+    'Select2MultipleField', 'QuerySelect2Field', 'JsonSelect2Field',
+    'JsonSelect2MultipleField', 'FormField'
+]
 
 
 class FormField(BaseFormField):
@@ -113,9 +115,8 @@ class ModelFieldList(FilterFieldListMixin, BaseModelFieldList):
         # instanciation so as to have permission filtering
         field_names = []
         labels = []
-        fieldsubform = self.unbound_field.bind(form=None,
-                                               name='dummy',
-                                               _meta=self.meta)
+        fieldsubform = self.unbound_field.bind(
+            form=None, name='dummy', _meta=self.meta)
         subform = fieldsubform.form_class(csrf_enabled=False)
         for f in subform:
             if f.is_hidden:
@@ -126,8 +127,8 @@ class ModelFieldList(FilterFieldListMixin, BaseModelFieldList):
 
         self._field_names = field_names
         self._field_labels = labels
-        self._field_nameTolabel = dict(zip(self._field_names,
-                                           self._field_labels))
+        self._field_nameTolabel = dict(
+            zip(self._field_names, self._field_labels))
 
     def __call__(self, **kwargs):
         """
@@ -170,8 +171,9 @@ class FileField(BaseFileField):
         self._has_uploads = False
 
         if allow_delete is not None:
-            if any(isinstance(v, DataRequired if allow_delete else Optional)
-                   for v in validators):
+            if any(
+                    isinstance(v, DataRequired if allow_delete else Optional)
+                    for v in validators):
                 raise ValueError(
                     "Field validators are conflicting with `allow_delete`,"
                     "validators={!r}, allow_delete={!r}".format(validators,
@@ -443,7 +445,7 @@ class QuerySelect2Field(SelectFieldBase):
 
     This field only works for queries on models whose primary key column(s)
     have a consistent string representation. This means it mostly only works
-    for those composed of string, unicode, and integer types. For the most
+    for those composed of string and integer types. For the most
     part, the primary keys will be auto-detected from the model, alternately
     pass a one-argument callable to `get_pk` which can return a unique
     comparable key.
@@ -502,7 +504,8 @@ class QuerySelect2Field(SelectFieldBase):
         if get_pk is None:
             if not has_identity_key:
                 raise Exception(
-                    'The sqlalchemy identity_key function could not be imported.')
+                    'The sqlalchemy identity_key function could not be imported.'
+                )
             self.get_pk = get_pk_from_identity
         else:
             self.get_pk = get_pk
@@ -525,8 +528,9 @@ class QuerySelect2Field(SelectFieldBase):
             if not self.multiple:
                 formdata = [formdata]
             formdata = set(formdata)
-            data = [obj for pk, obj in self._get_object_list()
-                    if pk in formdata]
+            data = [
+                obj for pk, obj in self._get_object_list() if pk in formdata
+            ]
             if all(hasattr(x, 'name') for x in data):
                 data = sorted(data, key=lambda x: x.name)
             else:
@@ -603,7 +607,7 @@ class JsonSelect2Field(SelectFieldBase):
 
     This field only works for queries on models whose primary key column(s)
     have a consistent string representation. This means it mostly only works
-    for those composed of string, unicode, and integer types. For the most
+    for those composed of string and integer types. For the most
     part, the primary keys will be auto-detected from the model, alternately
     pass a one-argument callable to `get_pk` which can return a unique
     comparable key.
@@ -682,8 +686,10 @@ class JsonSelect2Field(SelectFieldBase):
         if formdata:
             if not self.multiple:
                 formdata = [formdata]
-            data = [self.model_class.query.get(int(pk)) for pk in formdata
-                    if pk not in (u'', None)]
+            data = [
+                self.model_class.query.get(int(pk)) for pk in formdata
+                if pk not in (u'', None)
+            ]
             if not self.multiple:
                 data = data[0] if data else None
             self._set_data(data)
@@ -753,8 +759,8 @@ class LocaleSelectField(SelectField):
             return None
 
         raise ValueError(
-            'Value cannot be converted to Locale(), or is not None, {!r}'.format(
-                value))
+            'Value cannot be converted to Locale(), or is not None, {!r}'.
+            format(value))
 
     def iter_choices(self):
         if not self.flags.required:
