@@ -2,8 +2,8 @@
 """
 Field filters for WTForm.
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 from six import string_types
 
