@@ -4,8 +4,8 @@ Reusable widgets to be included in views.
 
 NOTE: code is currently quite messy. Needs to be refactored.
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import base64
 import cgi
@@ -17,8 +17,8 @@ from datetime import datetime
 import bleach
 import sqlalchemy as sa
 import wtforms
-from flask import (Markup, current_app, g, json, render_template,
-                   render_template_string)
+from flask import Markup, current_app, g, json, render_template, \
+    render_template_string
 from flask_babel import format_date, format_datetime, format_number, get_locale
 from flask_login import current_user
 from flask_wtf.file import FileField
@@ -150,8 +150,10 @@ class BaseTableView(object):
             offset = 1
 
         for idx, c in enumerate(self.columns, offset):
-            aoColumns.append({'asSorting': c['sorting'],
-                              'sWidth': str(c['width'])})
+            aoColumns.append({
+                'asSorting': c['sorting'],
+                'sWidth': str(c['width'])
+            })
             aaSorting.append([idx, c['sorting'][0]])
 
         datatable_options = {
@@ -167,15 +169,16 @@ class BaseTableView(object):
             'bLengthChange': False,
             'iDisplayLength': self.options.get('paginate_length', 50)
         }
-        js = render_template_string('''
+        js = render_template_string(
+            '''
         require(
             ['jquery', 'jquery.dataTables'],
             function($) {
                 $('#{{ table_id  }}').dataTable({{ options|tojson|safe }});
             });
         ''',
-                                    table_id=self.name,
-                                    options=datatable_options,)
+            table_id=self.name,
+            options=datatable_options,)
 
         table = []
         for entity in entities:
@@ -183,10 +186,9 @@ class BaseTableView(object):
 
         template = filter(bool, (self.options.get('template'),
                                  'widgets/render_table.html'))
-        return Markup(render_template(
-            template, table=table,
-            js=Markup(js),
-            view=self, **kwargs))
+        return Markup(
+            render_template(
+                template, table=table, js=Markup(js), view=self, **kwargs))
 
     def render_line(self, entity):
         line = []
@@ -302,8 +304,10 @@ class AjaxMainTableView(object):
 
     def render(self):
         aoColumns = [{'asSorting': []}] if self.show_controls else []
-        aoColumns += [{'asSorting': col['sorting'],
-                       'bSortable': col['sortable']} for col in self.columns]
+        aoColumns += [{
+            'asSorting': col['sorting'],
+            'bSortable': col['sortable']
+        } for col in self.columns]
         datatable_options = {
             'sDom': 'fFriltip',
             'aoColumns': aoColumns,
@@ -338,11 +342,12 @@ class AjaxMainTableView(object):
         for c in self.search_criterions:
             if not c.has_form_filter:
                 continue
-            d = dict(name=c.name,
-                     label=text_type(c.label),
-                     type=c.form_filter_type,
-                     args=c.form_filter_args,
-                     unset=c.form_unset_value,)
+            d = dict(
+                name=c.name,
+                label=text_type(c.label),
+                type=c.form_filter_type,
+                args=c.form_filter_args,
+                unset=c.form_unset_value,)
             if c.has_form_default_value:
                 d['defaultValue'] = c.form_default_value
 
@@ -352,9 +357,11 @@ class AjaxMainTableView(object):
             datatable_options[
                 'aoAdvancedSearchFilters'] = advanced_search_filters
 
-        return Markup(render_template('widgets/render_ajax_table.html',
-                                      datatable_options=datatable_options,
-                                      view=self))
+        return Markup(
+            render_template(
+                'widgets/render_ajax_table.html',
+                datatable_options=datatable_options,
+                view=self))
 
     def render_line(self, entity):
         line = []
@@ -451,13 +458,15 @@ class SingleView(object):
         template = filter(bool, (self.options.get('view_template'),
                                  'widgets/render_single.html'))
 
-        return Markup(render_template(template,
-                                      view=self,
-                                      related_views=related_views,
-                                      csrf_token=csrf.field(),
-                                      entity=item,
-                                      panels=panels,
-                                      form=form))
+        return Markup(
+            render_template(
+                template,
+                view=self,
+                related_views=related_views,
+                csrf_token=csrf.field(),
+                entity=item,
+                panels=panels,
+                form=form))
 
     def render_form(self, form, for_new=False, has_save_and_add_new=False):
         # Client-side rules for jQuery.validate
@@ -479,12 +488,14 @@ class SingleView(object):
         template = filter(bool, (self.options.get('edit_template'),
                                  'widgets/render_for_edit.html'))
 
-        return Markup(render_template(template,
-                                      view=self,
-                                      form=form,
-                                      for_new=for_new,
-                                      has_save_and_add_new=has_save_and_add_new,
-                                      rules=rules))
+        return Markup(
+            render_template(
+                template,
+                view=self,
+                form=form,
+                for_new=for_new,
+                has_save_and_add_new=has_save_and_add_new,
+                rules=rules))
 
     def label_for(self, field, mapper, name):
         label = field.label
@@ -624,8 +635,9 @@ class TextInput(wtforms.widgets.TextInput):
         if 'value' not in kwargs:
             kwargs['value'] = field._value()
 
-        return Markup(render_template_string(
-            u'''
+        return Markup(
+            render_template_string(
+                u'''
             <div class="input-group input-group-type-{{ widget.typename }}">
             {%- if widget.pre_icon %}
               <div class="input-group-addon">{{ widget.pre_icon }}</div>
@@ -636,8 +648,9 @@ class TextInput(wtforms.widgets.TextInput):
             {%- endif %}
             </div>
             ''',
-            widget=self,
-            params=self.html_params(name=field.name, **kwargs)))
+                widget=self,
+                params=self.html_params(
+                    name=field.name, **kwargs)))
 
     @property
     def typename(self):
@@ -709,13 +722,14 @@ class FileInput(object):
                 # due to debugtoolbar capturing template parameters
                 del data['file']
 
-        ctx = dict(id=field.id,
-                   field=field,
-                   widget=self,
-                   input=input_elem,
-                   button_label=button_label,
-                   existing=existing,
-                   uploaded=uploads)
+        ctx = dict(
+            id=field.id,
+            field=field,
+            widget=self,
+            input=input_elem,
+            button_label=button_label,
+            existing=existing,
+            uploaded=uploads)
         return Markup(render_template(self.template, **ctx))
 
     def build_exisiting_files_list(self, field):
@@ -769,12 +783,13 @@ class ImageInput(FileInput):
     data has to provide an attribute named `url`.
     """
 
-    def __init__(self,
-                 template='widgets/image_input.html',
-                 width=120,
-                 height=120,
-                 resize_mode=image.CROP,
-                 valid_extensions=('jpg', 'jpeg', 'png'),):
+    def __init__(
+            self,
+            template='widgets/image_input.html',
+            width=120,
+            height=120,
+            resize_mode=image.CROP,
+            valid_extensions=('jpg', 'jpeg', 'png'),):
         super(ImageInput, self).__init__(template=template)
         self.resize_mode = resize_mode
         self.valid_extensions = valid_extensions
@@ -788,8 +803,8 @@ class ImageInput(FileInput):
                 if hasattr(value, 'url'):
                     image_url = value.url
                 else:
-                    image_url = self.get_b64_thumb_url(self.get_thumb(
-                        value, self.width, self.height))
+                    image_url = self.get_b64_thumb_url(
+                        self.get_thumb(value, self.width, self.height))
 
                 data['image_url'] = image_url
 
@@ -804,8 +819,8 @@ class ImageInput(FileInput):
                     image_url = value.url
                 else:
                     with value.open('rb') as in_:
-                        image_url = self.get_b64_thumb_url(self.get_thumb(
-                            in_, self.width, self.height))
+                        image_url = self.get_b64_thumb_url(
+                            self.get_thumb(in_, self.width, self.height))
 
                 data['image_url'] = image_url
 
@@ -842,10 +857,8 @@ class ImageInput(FileInput):
         width, height = image.get_size(thumb)
 
         tmpl = u'<img src="{{ url }}" width="{{ width }}" height="{{ height }}" />'
-        return render_template_string(tmpl,
-                                      url=self.get_b64_thumb_url(thumb),
-                                      width=width,
-                                      height=height)
+        return render_template_string(
+            tmpl, url=self.get_b64_thumb_url(thumb), width=width, height=height)
 
 
 class Chosen(Select):
@@ -855,8 +868,10 @@ class Chosen(Select):
 
     def __call__(self, field, **kwargs):
         kwargs.setdefault('id', field.id)
-        html = [u'<select %s class="chzn-select">' %
-                html_params(name=field.name, **kwargs)]
+        html = [
+            u'<select %s class="chzn-select">' % html_params(
+                name=field.name, **kwargs)
+        ]
         for val, label, selected in field.iter_choices():
             html.append(self.render_option(val, label, selected))
         html.append(u'</select>')
@@ -883,8 +898,8 @@ class TagInput(Input):
         if 'value' not in kwargs:
             kwargs['value'] = field._value()
 
-        return HTMLString(u'<input %s>' % self.html_params(name=field.name,
-                                                           **kwargs))
+        return HTMLString(u'<input %s>' % self.html_params(
+            name=field.name, **kwargs))
 
 
 class DateInput(Input):
@@ -928,10 +943,8 @@ class DateInput(Input):
         s = u'<div {}>\n'.format(html_params(**attributes))
 
         s += u'  <input size="13" type="text" class="form-control" {} />\n'.format(
-            html_params(name=field_name,
-                        id=field_id,
-                        value=value,
-                        **kwargs))
+            html_params(
+                name=field_name, id=field_id, value=value, **kwargs))
         s += u'  <span class="input-group-addon"><i class="fa fa-calendar"></i></span>\n'
         s += u'</div>\n'
         return Markup(s)
@@ -995,14 +1008,17 @@ class TimeInput(Input):
             'data-modal-backdrop': self.modalBackdrop
         }
 
-        input_params = {k: Markup(json.dumps(v))
-                        for k, v in input_params.items()}
+        input_params = {
+            k: Markup(json.dumps(v))
+            for k, v in input_params.items()
+        }
 
-        ctx = dict(id=field_id,
-                   value=value,
-                   field=field,
-                   required=False,
-                   timepicker_attributes=input_params)
+        ctx = dict(
+            id=field_id,
+            value=value,
+            field=field,
+            required=False,
+            timepicker_attributes=input_params)
         return Markup(render_template(self.template, **ctx))
 
 
@@ -1212,8 +1228,8 @@ class MoneyWidget(TextInput):
         # units, which we don't want
         #
         # \u00A0: non-breakable whitespace
-        return u'{value}\u00A0{unit}'.format(value=format_number(val),
-                                             unit=unit)
+        return u'{value}\u00A0{unit}'.format(
+            value=format_number(val), unit=unit)
 
 
 class EmailWidget(TextInput):
@@ -1225,8 +1241,7 @@ class EmailWidget(TextInput):
             for entry in field.entries:
                 link = bleach.linkify(entry.data, parse_email=True)
                 if link:
-                    links = links + u' {}&nbsp;<i class="fa fa-envelope"></i><br>'.format(
-                        link)
+                    links += u' {}&nbsp;<i class="fa fa-envelope"></i><br>'.format(link)
         else:
             link = bleach.linkify(field.object_data, parse_email=True)
             if link:
@@ -1243,10 +1258,16 @@ class URLWidget(object):
 class RichTextWidget(object):
     template = 'widgets/richtext.html'
     allowed_tags = {
-        'a': {'href': True,
-              'title': True},
-        'abbr': {'title': True},
-        'acronym': {'title': True},
+        'a': {
+            'href': True,
+            'title': True
+        },
+        'abbr': {
+            'title': True
+        },
+        'acronym': {
+            'title': True
+        },
         'b': True,
         'blockquote': True,
         'br': True,
@@ -1259,7 +1280,9 @@ class RichTextWidget(object):
         'h5': True,
         'h6': True,
         'i': True,
-        'img': {'src': True},
+        'img': {
+            'src': True
+        },
         'li': True,
         'ol': True,
         'strong': True,
@@ -1277,10 +1300,8 @@ class RichTextWidget(object):
     def __call__(self, field, **kwargs):
         value = kwargs.pop('value') if 'value' in kwargs else field._value()
         kwargs.setdefault('allowed_tags', self.allowed_tags)
-        return render_template(self.template,
-                               field=field,
-                               value=value,
-                               kw=kwargs)
+        return render_template(
+            self.template, field=field, value=value, kw=kwargs)
 
 
 class ListWidget(wtforms.widgets.ListWidget):
@@ -1296,8 +1317,9 @@ class ListWidget(wtforms.widgets.ListWidget):
             return super(ListWidget, self).__call__(field, **kwargs)
 
         kwargs.setdefault('id', field.id)
-        html = [u'<%s %s>' %
-                (self.html_tag, wtforms.widgets.html_params(**kwargs))]
+        html = [
+            u'<%s %s>' % (self.html_tag, wtforms.widgets.html_params(**kwargs))
+        ]
         for subfield in field:
             html.append(u'<li>{}</li>'.format(subfield()))
 
@@ -1309,9 +1331,10 @@ class ListWidget(wtforms.widgets.ListWidget):
         is_empty = data == [] if field.multiple else data is None
 
         if not is_empty:
-            data = ([label for v, label, checked in field.iter_choices()
-                     if checked] if hasattr(field, 'iter_choices') and
-                    callable(field.iter_choices) else field.object_data)
+            data = ([
+                label for v, label, checked in field.iter_choices() if checked
+            ] if hasattr(field, 'iter_choices') and callable(field.iter_choices)
+                    else field.object_data)
         else:
             data = []
 
@@ -1370,9 +1393,9 @@ class TabularFieldListWidget(object):
             Data = namedtuple(data_type, field_names)
             labels = Data(*[f.label for f in field[0] if not f.is_hidden])
 
-        return Markup(render_template(self.template,
-                                      labels=labels,
-                                      field=field))
+        return Markup(
+            render_template(
+                self.template, labels=labels, field=field))
 
 
 class ModelListWidget(object):
@@ -1384,11 +1407,8 @@ class ModelListWidget(object):
         assert isinstance(field, ModelFieldList)
         value = field.object_data
         if not value:
-            return render_template(self.template,
-                                   field=field,
-                                   labels=(),
-                                   rows=(),
-                                   **kwargs)
+            return render_template(
+                self.template, field=field, labels=(), rows=(), **kwargs)
 
         field_names = field._field_names
         labels = field._field_labels
@@ -1404,11 +1424,8 @@ class ModelListWidget(object):
 
             rows.append(Data(*row))
 
-        rendered = render_template(self.template,
-                                   field=field,
-                                   labels=labels,
-                                   rows=rows,
-                                   **kwargs)
+        rendered = render_template(
+            self.template, field=field, labels=labels, rows=rows, **kwargs)
         return rendered
 
 
@@ -1446,8 +1463,10 @@ class Select2(Select):
         return Select.__call__(self, field, *args, **kwargs)
 
     def render_view(self, field, **kwargs):
-        labels = [text_type(label) for v, label, checked in field.iter_choices()
-                  if checked]
+        labels = [
+            text_type(label) for v, label, checked in field.iter_choices()
+            if checked
+        ]
         return u'; '.join(labels)
 
     @classmethod
@@ -1548,12 +1567,13 @@ class Select2Ajax(object):
 
         extra_args = Markup(html_params(**kwargs))
 
-        ctx = dict(field=field,
-                   name=field.name,
-                   id=field.id,
-                   input_value=input_value,
-                   json_data=json_data,
-                   required=not field.allow_blank,
-                   data_node_id=data_node_id,
-                   extra_args=extra_args)
+        ctx = dict(
+            field=field,
+            name=field.name,
+            id=field.id,
+            input_value=input_value,
+            json_data=json_data,
+            required=not field.allow_blank,
+            data_node_id=data_node_id,
+            extra_args=extra_args)
         return Markup(render_template(self.template, **ctx))
