@@ -2,8 +2,8 @@
 """
 View decorators for controlling some aspect of HTTP, mainly: Cache headers
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 from functools import wraps
 
