@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import logging
 
@@ -83,8 +83,8 @@ class TextSearchCriterion(BaseCriterion):
 
     def __init__(self, name, label='', attributes=None, search_fmt='%{q}%'):
         super(TextSearchCriterion, self).__init__(name, label)
-        self.attributes = dict.fromkeys(attributes
-                                        if attributes is not None else (name,))
+        self.attributes = dict.fromkeys(
+            attributes if attributes is not None else (name,))
         self._attributes_prepared = False
 
         if isinstance(search_fmt, string_types):
@@ -113,10 +113,12 @@ class TextSearchCriterion(BaseCriterion):
                              self.model.__class__.__name__, attr_name)
                 to_del.append(attr_name)
             else:
-                val.update(dict(attr=attr,
-                                name=name,
-                                model=model,
-                                rel_attr_name=rel_attr_name,))
+                val.update(
+                    dict(
+                        attr=attr,
+                        name=name,
+                        model=model,
+                        rel_attr_name=rel_attr_name,))
 
         for k in to_del:
             del self.attributes[k]
