@@ -1,8 +1,8 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 from flask import current_app
 from werkzeug.exceptions import BadRequest
@@ -12,15 +12,13 @@ from abilian.core.models.tag import Tag
 from abilian.i18n import _l
 from abilian.web import url_for
 from abilian.web.blueprints import Blueprint
-from abilian.web.views import (BaseObjectView, JSONView, ObjectCreate,
-                               ObjectDelete, ObjectEdit)
+from abilian.web.views import BaseObjectView, JSONView, ObjectCreate, \
+    ObjectDelete, ObjectEdit
 
 from .forms import TagForm
 
-bp = Blueprint('tags',
-               __name__,
-               url_prefix='/tags',
-               template_folder='templates')
+bp = Blueprint(
+    'tags', __name__, url_prefix='/tags', template_folder='templates')
 
 
 class BaseTagView(object):
@@ -42,7 +40,7 @@ class TagEdit(BaseTagView, ObjectEdit):
     _message_success = _l(u'Tag edited')
 
 
-edit_view = TagEdit.as_view(b'edit')
+edit_view = TagEdit.as_view('edit')
 bp.route('/manage/<int:object_id>/edit')(edit_view)
 
 
@@ -50,7 +48,7 @@ class TagCreate(BaseTagView, ObjectCreate):
     _message_success = _l(u'Tag created')
 
 
-create_view = TagCreate.as_view(b'create')
+create_view = TagCreate.as_view('create')
 bp.route('/manage/new')(create_view)
 
 
@@ -58,7 +56,7 @@ class TagDelete(BaseTagView, ObjectDelete):
     _message_success = _l(u'Tag deleted')
 
 
-delete_view = TagDelete.as_view(b'delete')
+delete_view = TagDelete.as_view('delete')
 bp.route('/manage/<int:object_id>/delete')(delete_view)
 
 # Tags on entities
@@ -96,7 +94,7 @@ class EntityTagList(BaseEntityTagView, BaseObjectView, JSONView):
         return dict(result=tags)
 
 
-entity_bp.route('/<int:object_id>/list')(EntityTagList.as_view(b'list'))
+entity_bp.route('/<int:object_id>/list')(EntityTagList.as_view('list'))
 
 
 class EntityTagManage(BaseEntityTagView, ObjectEdit):
@@ -117,10 +115,10 @@ class EntityTagManage(BaseEntityTagView, ObjectEdit):
         op(self.entity, ns=ns, label=label)
 
 
-entity_bp.route('/<int:object_id>/add')(EntityTagManage.as_view(b'add',
-                                                                mode='add'))
+entity_bp.route('/<int:object_id>/add')(EntityTagManage.as_view(
+    'add', mode='add'))
 entity_bp.route('/<int:object_id>/remove')(EntityTagManage.as_view(
-    b'remove', mode='remove'))
+    'remove', mode='remove'))
 
 
 class EntityTagEdit(ObjectEdit):
@@ -139,4 +137,4 @@ class EntityTagEdit(ObjectEdit):
         return self.view_url()
 
 
-entity_bp.route('/<int:object_id>/edit')(EntityTagEdit.as_view(b'edit'))
+entity_bp.route('/<int:object_id>/edit')(EntityTagEdit.as_view('edit'))
