@@ -1,8 +1,8 @@
 # coding=utf-8
 """
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import json
 import logging
@@ -13,6 +13,7 @@ from uuid import UUID, uuid1
 from celery import shared_task
 from flask import current_app
 from flask_login import AnonymousUserMixin
+from six import PY3
 
 from abilian.core import signals
 from abilian.web import url_for
@@ -108,7 +109,11 @@ class FileUploadsExtension(object):
         if metadata:
             meta_file = user_dir / '{}.metadata'.format(handle)
             with meta_file.open('wb') as out:
-                json.dump(metadata, out, skipkeys=True)
+                metadata_json = json.dumps(
+                    metadata, skipkeys=True, ensure_ascii=True)
+                if PY3:
+                    metadata_json = metadata_json.encode('ascii')
+                out.write(metadata_json)
 
         return handle
 
@@ -157,8 +162,9 @@ class FileUploadsExtension(object):
         return meta
 
     def remove_file(self, user, handle):
-        paths = (self.get_file(user, handle),
-                 self.get_metadata_file(user, handle),)
+        paths = (
+            self.get_file(user, handle),
+            self.get_metadata_file(user, handle),)
 
         for file_path in paths:
             if file_path is not None:
