@@ -127,9 +127,10 @@ class BaseBlobDownload(BaseFileDownload):
         blob = self.blob
         stream = blob.file.open('rb')
 
-        return send_file(stream,
-                         as_attachment=False,
-                         mimetype=self.content_type,
-                         cache_timeout=0,
-                         add_etags=False,
-                         conditional=False)
+        return send_file(
+            stream,
+            as_attachment=False,
+            mimetype=self.content_type,
+            cache_timeout=0,
+            add_etags=False,
+            conditional=False)
