@@ -1,6 +1,6 @@
 # coding=utf-8
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import inspect
 from operator import attrgetter, itemgetter
